|Kernel header for TI-68k programs
|Copyright (C) 2008  Martial Demolins

|This program is free software: you can redistribute it and/or modify
|it under the terms of the GNU General Public License as published by
|the Free Software Foundation, either version 3 of the License, or
|(at your option) any later version.

|This program is distributed in the hope that it will be useful,
|but WITHOUT ANY WARRANTY; without even the implied warranty of
|MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|GNU General Public License for more details.

|You should have received a copy of the GNU General Public License
|along with this program.  If not, see <http://www.gnu.org/licenses/>.


.ifndef	KERNEL_HEADER
	.xdef	KERNEL_HEADER
|=========================================
|	Macro which creates a section for a function, and which export this function
|	usage <FunctionSection function>
|=========================================
.macro	FunctionSection	function
	.xdef		\function
	.section	.text.\function,"x"
\function:
.endm

|=========================================
|	Macro which creates a section for data, and which export its adress
|	usage <DataSection dataname; data>
|=========================================
.macro	DataSection	dataname
	.xdef		\dataname
	.section	.data.\dataname,"d"
\dataname:
.endm

|=========================================
|	Macro which creates a section for a string, and which export its adress
|	usage <StringSection strname,string> (the string hasn't to be null terminated)
|=========================================
.macro	StringSection	strname, str
	.xdef		\strname
	.section	.data.string_\strname,"du"	|may be unaligned!
\strname:		.asciz				\str
.endm

|=======================================================================================
|
|Header file for kernel compilation for GNU as by Martial Demolins
|
|ROM calls from TIGCC (doorsos.h for a68k, to have ROM calls of ams2.xx and higher)
|RAM calls from PreOS (tios.h for a68k, to use ALL features of the kernel)
|
|=======================================================================================

|===================================
|	ROM calls (relocated)
|===================================
.set	ams__acos,				_ROM_CALL_F5
.set	ams__acosh,				_ROM_CALL_288
.set	ams__asin,				_ROM_CALL_F6
.set	ams__asinh,				_ROM_CALL_287
.set	ams__atan,				_ROM_CALL_F7
.set	ams__atan2,				_ROM_CALL_F8
.set	ams__atanh,				_ROM_CALL_289
.set	ams__cacos,				_ROM_CALL_13A
.set	ams__cacosh,				_ROM_CALL_13D
.set	ams__casin,				_ROM_CALL_13B
.set	ams__casinh,				_ROM_CALL_13E
.set	ams__catan,				_ROM_CALL_13C
.set	ams__catanh,				_ROM_CALL_13F
.set	ams__ccos,				_ROM_CALL_140
.set	ams__ccosh,				_ROM_CALL_143
.set	ams__ceil,				_ROM_CALL_105
.set	ams__cexp,				_ROM_CALL_149
.set	ams__cln,				_ROM_CALL_147
.set	ams__clog10,				_ROM_CALL_148
.set	ams__cos,				_ROM_CALL_F9
.set	ams__cosh,				_ROM_CALL_FC
.set	ams__csin,				_ROM_CALL_141
.set	ams__csinh,				_ROM_CALL_144
.set	ams__csqrt,				_ROM_CALL_146
.set	ams__ctan,				_ROM_CALL_142
.set	ams__ctanh,				_ROM_CALL_145
.set	ams__exp,				_ROM_CALL_FF
.set	ams__fabs,				_ROM_CALL_106
.set	ams__fadd,				_ROM_CALL_B6
.set	ams__fcmp,				_ROM_CALL_BB
.set	ams__fdiv,				_ROM_CALL_B9
.set	ams__flt,				_ROM_CALL_BD
.set	ams__float_class,			_ROM_CALL_2FA
.set	ams__floor,				_ROM_CALL_107
.set	ams__fmod,				_ROM_CALL_108
.set	ams__fmul,				_ROM_CALL_B8
.set	ams__fneg,				_ROM_CALL_BA
.set	ams__fpisanint,				_ROM_CALL_172
.set	ams__fpisodd,				_ROM_CALL_173
.set	ams__frexp10,				_ROM_CALL_2FB
.set	ams__fsub,				_ROM_CALL_B7
.set	ams__is_float_infinity,			_ROM_CALL_2FF
.set	ams__is_float_negative_zero,		_ROM_CALL_300
.set	ams__is_float_positive_zero,		_ROM_CALL_301
.set	ams__is_float_signed_infinity,		_ROM_CALL_302
.set	ams__is_float_transfinite,		_ROM_CALL_303
.set	ams__is_float_unsigned_inf_or_nan,	_ROM_CALL_304
.set	ams__is_float_unsigned_zero,		_ROM_CALL_305
.set	ams__is_inf,				_ROM_CALL_2FF
.set	ams__is_nan,				_ROM_CALL_306
.set	ams__is_nzero,				_ROM_CALL_300
.set	ams__is_pzero,				_ROM_CALL_301
.set	ams__is_sinf,				_ROM_CALL_302
.set	ams__is_transfinite,			_ROM_CALL_303
.set	ams__is_uinf_or_nan,			_ROM_CALL_304
.set	ams__is_uzero,				_ROM_CALL_305
.set	ams__itrig,				_ROM_CALL_28A
.set	ams__log,				_ROM_CALL_100
.set	ams__log10,				_ROM_CALL_101
.set	ams__modf,				_ROM_CALL_102
.set	ams__pow,				_ROM_CALL_103
.set	ams__round12,				_ROM_CALL_174
.set	ams__round12_err,			_ROM_CALL_227
.set	ams__round14,				_ROM_CALL_175
.set	ams__sin,				_ROM_CALL_FA
.set	ams__sincos,				_ROM_CALL_286
.set	ams__sinh,				_ROM_CALL_FD
.set	ams__sqrt,				_ROM_CALL_104
.set	ams__tan,				_ROM_CALL_FB
.set	ams__tanh,				_ROM_CALL_FE
.set	ams__trig,				_ROM_CALL_28B
.set	ams__trunc,				_ROM_CALL_BC
.set	ams__all_tail,				_ROM_CALL_3B5
.set	ams__any_tail,				_ROM_CALL_3B6
.set	ams__are_expressions_identical,		_ROM_CALL_2BF
.set	ams__can_be_approxed,			_ROM_CALL_2F5
.set	ams__check_estack_size,			_ROM_CALL_2C2
.set	ams__compare_complex_magnitudes,	_ROM_CALL_2F6
.set	ams__compare_expressions,		_ROM_CALL_2C0
.set	ams__compare_Floats,			_ROM_CALL_2F7
.set	ams__deleted_between,			_ROM_CALL_2C4
.set	ams__deleted_expression,		_ROM_CALL_2C6
.set	ams__delete_between,			_ROM_CALL_2C3
.set	ams__delete_expression,			_ROM_CALL_2C5
.set	ams__did_push_cnvrt_Float_to_integer,	_ROM_CALL_2F8
.set	ams__display_statements,		_ROM_CALL_4E
.set	ams__estack_number_to_Float,		_ROM_CALL_2F9
.set	ams__estack_to_short,			_ROM_CALL_2C7
.set	ams__estack_to_ushort,			_ROM_CALL_2C8
.set	ams__factor_base_index,			_ROM_CALL_2C9
.set	ams__factor_exponent_index,		_ROM_CALL_2CA
.set	ams__gcd_exact_whole_Floats,		_ROM_CALL_2FC
.set	ams__GetValue,				_ROM_CALL_2CB
.set	ams__get_key_ptr,			_ROM_CALL_2B7
.set	ams__HToESI,				_ROM_CALL_247
.set	ams__im_index,				_ROM_CALL_2CC
.set	ams__index_below_display_expression_aux,	_ROM_CALL_2B6
.set	ams__index_main_var,			_ROM_CALL_2CF
.set	ams__index_numeric_term,		_ROM_CALL_2CD
.set	ams__index_of_lead_base_of_lead_term,	_ROM_CALL_2CE
.set	ams__is_advanced_tag,			_ROM_CALL_2D0
.set	ams__is_antisymmetric,			_ROM_CALL_2D1
.set	ams__is_complex_number,			_ROM_CALL_2D2
.set	ams__is_complex0,			_ROM_CALL_2D3
.set	ams__is_Float_exact_whole_number,	_ROM_CALL_2FE
.set	ams__is_free_of_tag,			_ROM_CALL_2D4
.set	ams__is_independent_of,			_ROM_CALL_2D5
.set	ams__is_independent_of_de_seq_vars,	_ROM_CALL_2D6
.set	ams__is_independent_of_elements,	_ROM_CALL_2D8
.set	ams__is_independent_of_tail,		_ROM_CALL_2D7
.set	ams__is_matrix,				_ROM_CALL_3B7
.set	ams__is_monomial,			_ROM_CALL_2D9
.set	ams__is_monomial_in_kernel,		_ROM_CALL_2DA
.set	ams__is_narrowly_independent_of,	_ROM_CALL_2DB
.set	ams__is_square_matrix,			_ROM_CALL_3B8
.set	ams__is_symmetric,			_ROM_CALL_2DC
.set	ams__bottom_estack,			_ROM_CALL_432
.set	ams__is_valid_smap_aggregate,		_ROM_CALL_3B9
.set	ams__last_element_index,		_ROM_CALL_3BA
.set	ams__lead_base_index,			_ROM_CALL_2DE
.set	ams__lead_exponent_index,		_ROM_CALL_2DF
.set	ams__lead_factor_index,			_ROM_CALL_2E0
.set	ams__lead_term_index,			_ROM_CALL_2E1
.set	ams__likely_approx_to_complex_number,	_ROM_CALL_307
.set	ams__likely_approx_to_number,		_ROM_CALL_308
.set	ams__main_gen_var_index,		_ROM_CALL_2E2
.set	ams__map_tail,				_ROM_CALL_3BB
.set	ams__map_tail_Int,			_ROM_CALL_3BC
.set	ams__map_unary_over_comparison,		_ROM_CALL_2E3
.set	ams__min_quantum,			_ROM_CALL_2E4
.set	ams__moved_between_to_top,		_ROM_CALL_2E6
.set	ams__move_between_to_top,		_ROM_CALL_2E5
.set	ams__next_expression_index,		_ROM_CALL_10A
.set	ams__NG_approxESI,			_ROM_CALL_25C
.set	ams__NG_execute,			_ROM_CALL_25D
.set	ams__NG_graphESI,			_ROM_CALL_25E
.set	ams__NG_rationalESI,			_ROM_CALL_25F
.set	ams__NG_RPNToText,			_ROM_CALL_25B
.set	ams__NG_tokenize,			_ROM_CALL_260
.set	ams__norm1_complex_Float,		_ROM_CALL_309
.set	ams__numeric_factor_index,		_ROM_CALL_2E7
.set	ams__Parms2D,				_ROM_CALL_4D
.set	ams__Parse1DExpr,			_ROM_CALL_4F
.set	ams__Parse2DExpr,			_ROM_CALL_4A
.set	ams__Parse2DMultiExpr,			_ROM_CALL_4B
.set	ams__Print2DExpr,			_ROM_CALL_4C
.set	ams__push_ANSI_string,			_ROM_CALL_48A
.set	ams__push_between,			_ROM_CALL_2E8
.set	ams__push_cnvrt_integer_if_whole_nmb,	_ROM_CALL_30D
.set	ams__push_END_TAG,			_ROM_CALL_263
.set	ams__push_expr2_quantum,		_ROM_CALL_2EA
.set	ams__push_expr_quantum,			_ROM_CALL_2E9
.set	ams__push_Float,			_ROM_CALL_30A
.set	ams__push_Float_to_nonneg_int,		_ROM_CALL_30B
.set	ams__push_Float_to_rat,			_ROM_CALL_30C
.set	ams__push_internal_simplify,		_ROM_CALL_4F8
.set	ams__push_LIST_TAG,			_ROM_CALL_264
.set	ams__ARb_real_count,			_ROM_CALL_5C2
.set	ams__push_next_arb_int,			_ROM_CALL_2EB
.set	ams__push_next_arb_real,		_ROM_CALL_2EC
.set	ams__push_next_internal_var,		_ROM_CALL_2ED
.set	ams__push_offset_array,			_ROM_CALL_3C4
.set	ams__push_overflow_to_infinity,		_ROM_CALL_30E
.set	ams__push_parse_text,			_ROM_CALL_3CA
.set	ams__push_zstr,				_ROM_CALL_48A
.set	ams__push_quantum,			_ROM_CALL_2EE
.set	ams__push_quantum_pair,			_ROM_CALL_2EF
.set	ams__push_reversed_tail,		_ROM_CALL_3BF
.set	ams__push_round_Float,			_ROM_CALL_310
.set	ams__reductum_index,			_ROM_CALL_2F0
.set	ams__remaining_element_count,		_ROM_CALL_3C3
.set	ams__remaining_factors_index,		_ROM_CALL_2F1
.set	ams__reset_control_flags,		_ROM_CALL_2F4
.set	ams__reset_estack_size,			_ROM_CALL_2F3
.set	ams__re_index,				_ROM_CALL_2F2
.set	ams__should_and_did_push_approx_arg2,	_ROM_CALL_311
.set	ams__signum_Float,			_ROM_CALL_312
.set	ams__top_estack,			_ROM_CALL_109
.set	ams__is_tail_independent_of,		_ROM_CALL_2DD
.set	ams__push_transpose_aux,		_ROM_CALL_3C1
.set	ams__TokenizeSymName,			_ROM_CALL_80
.set	ams__push_expression,			_ROM_CALL_44D
.set	ams__ARb_int_count,			_ROM_CALL_5C3
.set	ams__push_long_to_integer,		_ROM_CALL_4E3
.set	ams__push_ulong_to_integer,		_ROM_CALL_4E4
.set	ams__push_ushort_to_integer,		_ROM_CALL_4E5
.set	ams__is_never0,				_ROM_CALL_577
.set	ams__is_minus1,				_ROM_CALL_508
.set	ams__is_negative,			_ROM_CALL_575
.set	ams__integer_non_unknown,		_ROM_CALL_50C
.set	ams__is_nonnegative,			_ROM_CALL_574
.set	ams__is_nonpositive,			_ROM_CALL_576
.set	ams__is_positive,			_ROM_CALL_573
.set	ams__is_whole_number,			_ROM_CALL_50B
.set	ams__is0,				_ROM_CALL_269
.set	ams__is1,				_ROM_CALL_2FD
.set	ams__is_totally_polynomial,		_ROM_CALL_56C
.set	ams__is_polynomial_in_var_or_kern,	_ROM_CALL_56B
.set	ams__is_constant,			_ROM_CALL_593
.set	ams__is_variable,			_ROM_CALL_488
.set	ams__negate_top,			_ROM_CALL_525
.set	ams__add1_to_top,			_ROM_CALL_51D
.set	ams__and_onto_top,			_ROM_CALL_579
.set	ams__add_to_top,			_ROM_CALL_518
.set	ams__push_simplify,			_ROM_CALL_44E
.set	ams__subtract_from_top,			_ROM_CALL_51B
.set	ams__subtract1_from_top,		_ROM_CALL_51E
.set	ams__ABT_dialog,			_ROM_CALL_10D
.set	ams__CAT_dialog,			_ROM_CALL_125
.set	ams__EV_captureEvents,			_ROM_CALL_C6
.set	ams__EV_centralDispatcher,		_ROM_CALL_156
.set	ams__EV_clearPasteString,		_ROM_CALL_C7
.set	ams__EV_defaultHandler,			_ROM_CALL_157
.set	ams__EV_eventLoop,			_ROM_CALL_158
.set	ams__EV_getc,				_ROM_CALL_C8
.set	ams__EV_getSplitRect,			_ROM_CALL_C9
.set	ams__EV_hook,				_ROM_CALL_2A3
.set	ams__EV_notifySwitchGraph,		_ROM_CALL_CA
.set	ams__EV_paintOneWindow,			_ROM_CALL_CB
.set	ams__EV_paintWindows,			_ROM_CALL_CC
.set	ams__EV_registerMenu,			_ROM_CALL_159
.set	ams__EV_restorePainting,		_ROM_CALL_CD
.set	ams__EV_sendEvent,			_ROM_CALL_CE
.set	ams__EV_sendEventSide,			_ROM_CALL_CF
.set	ams__EV_sendString,			_ROM_CALL_D0
.set	ams__EV_setCmdCheck,			_ROM_CALL_D1
.set	ams__EV_setCmdState,			_ROM_CALL_D2
.set	ams__EV_setFKeyState,			_ROM_CALL_D3
.set	ams__EV_startApp,			_ROM_CALL_D4
.set	ams__EV_startSide,			_ROM_CALL_D5
.set	ams__EV_startTask,			_ROM_CALL_D6
.set	ams__EV_suspendPainting,		_ROM_CALL_D7
.set	ams__EV_switch,				_ROM_CALL_D8
.set	ams__MO_option,				_ROM_CALL_447
.set	ams__MO_currentOptions,			_ROM_CALL_D9
.set	ams__MO_defaults,			_ROM_CALL_DA
.set	ams__MO_digestOptions,			_ROM_CALL_DB
.set	ams__MO_isMultigraphTask,		_ROM_CALL_DC
.set	ams__MO_modeDialog,			_ROM_CALL_DD
.set	ams__MO_notifyModeChange,		_ROM_CALL_DE
.set	ams__MO_sendQuit,			_ROM_CALL_DF
.set	ams__handleVarLinkKey,			_ROM_CALL_129
.set	ams__handleRclKey,			_ROM_CALL_14F
.set	ams__ModeSettings,			_ROM_CALL_447
.set	ams__AB_prodid,				_ROM_CALL_29D
.set	ams__AB_prodname,			_ROM_CALL_29E
.set	ams__AB_serno,				_ROM_CALL_29F
.set	ams__CB_fetchTEXT,			_ROM_CALL_C2
.set	ams__CB_replaceTEXT,			_ROM_CALL_C1
.set	ams__CU_restore,			_ROM_CALL_C3
.set	ams__CU_start,				_ROM_CALL_C4
.set	ams__CU_stop,				_ROM_CALL_C5
.set	ams__EX_patch,				_ROM_CALL_15A
.set	ams__HelpKeys,				_ROM_CALL_181
.set	ams__idle,				_ROM_CALL_29B
.set	ams__NeedStack,				_ROM_CALL_A4
.set	ams__off,				_ROM_CALL_29A
.set	ams__OSCheckBreak,			_ROM_CALL_EC
.set	ams__OSClearBreak,			_ROM_CALL_ED
.set	ams__OSContrastDn,			_ROM_CALL_297
.set	ams__OSContrastUp,			_ROM_CALL_296
.set	ams__OSdequeue,				_ROM_CALL_3AA
.set	ams__OSDisableBreak,			_ROM_CALL_EF
.set	ams__OSEnableBreak,			_ROM_CALL_EE
.set	ams__OSenqueue,				_ROM_CALL_3A9
.set	ams__OSFreeTimer,			_ROM_CALL_F1
.set	ams__OSqclear,				_ROM_CALL_3AD
.set	ams__OSqhead,				_ROM_CALL_3AC
.set	ams__OSqinquire,			_ROM_CALL_3AB
.set	ams__OSRegisterTimer,			_ROM_CALL_F0
.set	ams__OSReset,				_ROM_CALL_294
.set	ams__OSSetSR,				_ROM_CALL_29C
.set	ams__OSTimerCurVal,			_ROM_CALL_F2
.set	ams__OSTimerExpired,			_ROM_CALL_F3
.set	ams__OSTimerRestart,			_ROM_CALL_F4
.set	ams__QModeKey,				_ROM_CALL_182
.set	ams__QSysKey,				_ROM_CALL_183
.set	ams__SumStoChkMem,			_ROM_CALL_295
.set	ams__WordInList,			_ROM_CALL_184
.set	ams__XR_stringPtr,			_ROM_CALL_293
.set	ams__CU_cursorState,			_ROM_CALL_503
.set	ams__FiftyMsecTick,			_ROM_CALL_4FC
.set	ams__ReleaseVersion,			_ROM_CALL_440
.set	ams__ReleaseDate,			_ROM_CALL_43F
.set	ams__AB_getGateArrayVersion,		_ROM_CALL_15E
.set	ams__EX_getBasecodeParmBlock,		_ROM_CALL_5DA
.set	ams__ST_angle,				_ROM_CALL_E0
.set	ams__ST_batt,				_ROM_CALL_E1
.set	ams__ST_busy,				_ROM_CALL_E2
.set	ams__ST_eraseHelp,			_ROM_CALL_E3
.set	ams__ST_folder,				_ROM_CALL_E4
.set	ams__ST_graph,				_ROM_CALL_E5
.set	ams__ST_helpMsg,			_ROM_CALL_E6
.set	ams__ST_modKey,				_ROM_CALL_E7
.set	ams__ST_precision,			_ROM_CALL_E8
.set	ams__ST_readOnly,			_ROM_CALL_E9
.set	ams__ST_refDsp,				_ROM_CALL_EB
.set	ams__ST_stack,				_ROM_CALL_EA
.set	ams__ST_progressIncrement,		_ROM_CALL_4DA
.set	ams__ST_progressBar,			_ROM_CALL_4D8
.set	ams__ST_progressDismiss,		_ROM_CALL_4DB
.set	ams__ST_progressUpdate,			_ROM_CALL_4D9
.set	ams__AddSymToFolder,			_ROM_CALL_70
.set	ams__DerefSym,				_ROM_CALL_79
.set	ams__EM_moveSymFromExtMem,		_ROM_CALL_161
.set	ams__EM_moveSymToExtMem,		_ROM_CALL_162
.set	ams__EM_twinSymFromExtMem,		_ROM_CALL_166
.set	ams__FindSymInFolder,			_ROM_CALL_71
.set	ams__FolderAdd,				_ROM_CALL_64
.set	ams__FolderAddTemp,			_ROM_CALL_73
.set	ams__FolderClear,			_ROM_CALL_66
.set	ams__FolderCount,			_ROM_CALL_6B
.set	ams__FolderCur,				_ROM_CALL_65
.set	ams__FolderCurTemp,			_ROM_CALL_72
.set	ams__FolderDel,				_ROM_CALL_66
.set	ams__FolderDelAllTemp,			_ROM_CALL_75
.set	ams__FolderDelTemp,			_ROM_CALL_74
.set	ams__FolderFind,			_ROM_CALL_67
.set	ams__FolderGetCur,			_ROM_CALL_68
.set	ams__FolderOp,				_ROM_CALL_69
.set	ams__FolderRename,			_ROM_CALL_6A
.set	ams__HSymDel,				_ROM_CALL_5F
.set	ams__HSYMtoName,			_ROM_CALL_7A
.set	ams__IsMainFolderStr,			_ROM_CALL_77
.set	ams__MakeHSym,				_ROM_CALL_282
.set	ams__SymAdd,				_ROM_CALL_5C
.set	ams__SymAddMain,			_ROM_CALL_5D
.set	ams__SymAddTwin,			_ROM_CALL_27F
.set	ams__SymCmp,				_ROM_CALL_81
.set	ams__SymCpy,				_ROM_CALL_82
.set	ams__SymCpy0,				_ROM_CALL_83
.set	ams__SymDel,				_ROM_CALL_5E
.set	ams__SymDelTwin,			_ROM_CALL_280
.set	ams__SymFind,				_ROM_CALL_60
.set	ams__SymFindFirst,			_ROM_CALL_6C
.set	ams__SymFindFolderName,			_ROM_CALL_6F
.set	ams__SymFindHome,			_ROM_CALL_62
.set	ams__SymFindMain,			_ROM_CALL_61
.set	ams__SymFindNext,			_ROM_CALL_6D
.set	ams__SymFindPrev,			_ROM_CALL_6E
.set	ams__SymFindPtr,			_ROM_CALL_283
.set	ams__SymMove,				_ROM_CALL_63
.set	ams__TempFolderName,			_ROM_CALL_76
.set	ams__TokToStrN,				_ROM_CALL_7C
.set	ams__StrToTokN,				_ROM_CALL_7B
.set	ams__ClearUserDef,			_ROM_CALL_7E
.set	ams__CheckLinkLockFlag,			_ROM_CALL_7F
.set	ams__VarRecall,				_ROM_CALL_85
.set	ams__VarStore,				_ROM_CALL_86
.set	ams__QSysProtected,			_ROM_CALL_88
.set	ams__SetOK,				_ROM_CALL_456
.set	ams__checkCurrent,			_ROM_CALL_121
.set	ams__CheckReservedName,			_ROM_CALL_8B
.set	ams__CheckSysFunc,			_ROM_CALL_89
.set	ams__EX_stoBCD,				_ROM_CALL_C0
.set	ams__ValidateSymName,			_ROM_CALL_84
.set	ams__SymSysVar,				_ROM_CALL_8C
.set	ams__ResetSymFlags,			_ROM_CALL_8E
.set	ams__partial_len,			_ROM_CALL_11C
.set	ams__GetDataType,			_ROM_CALL_435
.set	ams__SmapTypeStrings,			_ROM_CALL_436
.set	ams__GetFuncPrgmBodyPtr,		_ROM_CALL_43A
.set	ams__free,				_ROM_CALL_A3
.set	ams__FreeHandles,			_ROM_CALL_23B
.set	ams__HeapAlloc,				_ROM_CALL_90
.set	ams__HeapAllocESTACK,			_ROM_CALL_91
.set	ams__HeapAllocHigh,			_ROM_CALL_92
.set	ams__HeapAllocHighThrow,		_ROM_CALL_94
.set	ams__HeapAllocPtr,			_ROM_CALL_A2
.set	ams__HeapAllocThrow,			_ROM_CALL_93
.set	ams__HeapAvail,				_ROM_CALL_8F
.set	ams__HeapCompress,			_ROM_CALL_95
.set	ams__HeapDeref,				_ROM_CALL_96
.set	ams__HeapEnd,				_ROM_CALL_A1
.set	ams__HeapFreeIndir,			_ROM_CALL_98
.set	ams__HeapFreePtr,			_ROM_CALL_A3
.set	ams__HeapFree,				_ROM_CALL_97
.set	ams__HeapGetHandle,			_ROM_CALL_239
.set	ams__HeapGetLock,			_ROM_CALL_9B
.set	ams__HeapLock,				_ROM_CALL_9A
.set	ams__HeapMax,				_ROM_CALL_9C
.set	ams__HeapMoveHigh,			_ROM_CALL_A0
.set	ams__HeapPtrToHandle,			_ROM_CALL_23A
.set	ams__HeapRealloc,			_ROM_CALL_9D
.set	ams__HeapSize,				_ROM_CALL_9E
.set	ams__HeapUnlock,			_ROM_CALL_9F
.set	ams__HLock,				_ROM_CALL_99
.set	ams__malloc,				_ROM_CALL_A2
.set	ams__HeapWalk,				_ROM_CALL_12C
.set	ams__HeapShuffle,			_ROM_CALL_474
.set	ams__EX_getArg,				_ROM_CALL_BE
.set	ams__EX_getBCD,				_ROM_CALL_BF
.set	ams__RemainingArgCnt,			_ROM_CALL_3C3
.set	ams__GKeyDown,				_ROM_CALL_17F
.set	ams__GKeyFlush,				_ROM_CALL_180
.set	ams__GKeyIn,				_ROM_CALL_17E
.set	ams__kbhit,				_ROM_CALL_52
.set	ams__ngetchx,				_ROM_CALL_51
.set	ams__OSGetStatKeys,			_ROM_CALL_299
.set	ams__OSInitBetweenKeyDelay,		_ROM_CALL_249
.set	ams__pushkey,				_ROM_CALL_50
.set	ams__OSInitKeyInitDelay,		_ROM_CALL_248
.set	ams__alphaLockOn,			_ROM_CALL_481
.set	ams__alphaLockOff,			_ROM_CALL_482
.set	ams__SetAlphaStatus,			_ROM_CALL_163
.set	ams__GetAlphaStatus,			_ROM_CALL_164
.set	ams__KeyYesOrNo,			_ROM_CALL_3EB
.set	ams__OSFastArrows,			_ROM_CALL_15C
.set	ams__restoreAlphaLock,			_ROM_CALL_483
.set	ams__KB_AUTOREPEAT,			_ROM_CALL_15C
.set	ams__BitmapGet,				_ROM_CALL_185
.set	ams__BitmapInit,			_ROM_CALL_186
.set	ams__BitmapPut,				_ROM_CALL_187
.set	ams__BitmapSize,			_ROM_CALL_188
.set	ams__ClrScr,				_ROM_CALL_19E
.set	ams__DrawChar,				_ROM_CALL_1A4
.set	ams__DrawClipChar,			_ROM_CALL_191
.set	ams__DrawClipEllipse,			_ROM_CALL_192
.set	ams__DrawClipLine,			_ROM_CALL_193
.set	ams__DrawClipPix,			_ROM_CALL_194
.set	ams__DrawClipRect,			_ROM_CALL_195
.set	ams__DrawFkey,				_ROM_CALL_1A5
.set	ams__DrawIcon,				_ROM_CALL_1A6
.set	ams__DrawLine,				_ROM_CALL_1A7
.set	ams__DrawMultiLines,			_ROM_CALL_196
.set	ams__DrawPix,				_ROM_CALL_1A8
.set	ams__CalcBitmapSize,			_ROM_CALL_3EF
.set	ams__DrawStr,				_ROM_CALL_1A9
.set	ams__DrawStrWidth,			_ROM_CALL_197
.set	ams__LineTo,				_ROM_CALL_19C
.set	ams__FillLines2,			_ROM_CALL_199
.set	ams__FillTriangle,			_ROM_CALL_198
.set	ams__FontCharWidth,			_ROM_CALL_190
.set	ams__FontGetSys,			_ROM_CALL_18E
.set	ams__FontSetSys,			_ROM_CALL_18F
.set	ams__GetPix,				_ROM_CALL_19F
.set	ams__ScrRect,				_ROM_CALL_2F
.set	ams__MoveTo,				_ROM_CALL_19D
.set	ams__PortRestore,			_ROM_CALL_1A3
.set	ams__PortSet,				_ROM_CALL_1A2
.set	ams__QScrRectOverlap,			_ROM_CALL_18D
.set	ams__RestoreScrState,			_ROM_CALL_1A1
.set	ams__SaveScrState,			_ROM_CALL_1A0
.set	ams__ScrRectFill,			_ROM_CALL_189
.set	ams__ScrRectOverlap,			_ROM_CALL_18A
.set	ams__ScrRectScroll,			_ROM_CALL_18B
.set	ams__ScrRectShift,			_ROM_CALL_18C
.set	ams__ScrToHome,				_ROM_CALL_2E
.set	ams__ScrToWin,				_ROM_CALL_2D
.set	ams__SetCurAttr,			_ROM_CALL_19A
.set	ams__SetCurClip,			_ROM_CALL_19B
.set	ams__ClientToScr,			_ROM_CALL_42C
.set	ams__DrawStrWidthP,			_ROM_CALL_3EE
.set	ams__MakeScrRect,			_ROM_CALL_42D
.set	ams__DrawWinBorder,			_ROM_CALL_27
.set	ams__FirstWindow,			_ROM_CALL_0
.set	ams__MakeWinRect,			_ROM_CALL_2C
.set	ams__RectWinToScr,			_ROM_CALL_2A
.set	ams__RectWinToWin,			_ROM_CALL_29
.set	ams__WinActivate,			_ROM_CALL_1
.set	ams__WinAttr,				_ROM_CALL_2
.set	ams__WinBackground,			_ROM_CALL_4
.set	ams__WinBackupToScr,			_ROM_CALL_3
.set	ams__WinBegin,				_ROM_CALL_5
.set	ams__WinBitmapGet,			_ROM_CALL_6
.set	ams__WinBitmapPut,			_ROM_CALL_7
.set	ams__WinBitmapSize,			_ROM_CALL_8
.set	ams__WinChar,				_ROM_CALL_A
.set	ams__WinCharXY,				_ROM_CALL_9
.set	ams__WinClose,				_ROM_CALL_B
.set	ams__WinClr,				_ROM_CALL_C
.set	ams__WinDeactivate,			_ROM_CALL_D
.set	ams__WinDupStat,			_ROM_CALL_E
.set	ams__WinEllipse,			_ROM_CALL_F
.set	ams__WinFill,				_ROM_CALL_10
.set	ams__WinFillLines2,			_ROM_CALL_11
.set	ams__WinFillTriangle,			_ROM_CALL_12
.set	ams__WinFont,				_ROM_CALL_13
.set	ams__WinGetCursor,			_ROM_CALL_14
.set	ams__WinHeight,				_ROM_CALL_292
.set	ams__WinHide,				_ROM_CALL_15
.set	ams__WinHome,				_ROM_CALL_16
.set	ams__WinLine,				_ROM_CALL_17
.set	ams__WinLineNC,				_ROM_CALL_18
.set	ams__WinLineRel,			_ROM_CALL_1A
.set	ams__WinLineTo,				_ROM_CALL_19
.set	ams__WinMoveCursor,			_ROM_CALL_1B
.set	ams__WinMoveRel,			_ROM_CALL_1D
.set	ams__WinMoveTo,				_ROM_CALL_1C
.set	ams__WinOpen,				_ROM_CALL_1E
.set	ams__WinPixGet,				_ROM_CALL_1F
.set	ams__WinPixSet,				_ROM_CALL_20
.set	ams__WinRect,				_ROM_CALL_21
.set	ams__WinReOpen,				_ROM_CALL_22
.set	ams__WinScrollH,			_ROM_CALL_23
.set	ams__WinScrollV,			_ROM_CALL_24
.set	ams__WinStr,				_ROM_CALL_25
.set	ams__WinStrXY,				_ROM_CALL_26
.set	ams__WinWidth,				_ROM_CALL_291
.set	ams__DrawStaticButton,			_ROM_CALL_35
.set	ams__SetWinClip,			_ROM_CALL_42E
.set	ams__BN_powerMod,			_ROM_CALL_123
.set	ams__BN_power17Mod,			_ROM_CALL_122
.set	ams__BN_prodMod,			_ROM_CALL_124
.set	ams__cdecrypt,				_ROM_CALL_127
.set	ams__MD5Done,				_ROM_CALL_257
.set	ams__MD5Final,				_ROM_CALL_256
.set	ams__MD5Init,				_ROM_CALL_254
.set	ams__MD5Update,				_ROM_CALL_255
.set	ams__Dialog,				_ROM_CALL_30
.set	ams__DialogAdd,				_ROM_CALL_33
.set	ams__DialogDo,				_ROM_CALL_32
.set	ams__DialogNew,				_ROM_CALL_34
.set	ams__DlgMessage,			_ROM_CALL_1B4
.set	ams__VarNew,				_ROM_CALL_28E
.set	ams__VarOpen,				_ROM_CALL_28C
.set	ams__VarSaveAs,				_ROM_CALL_28D
.set	ams__ERD_dialog,			_ROM_CALL_151
.set	ams__ERD_process,			_ROM_CALL_152
.set	ams__ER_catch,				_ROM_CALL_154
.set	ams__ER_success,			_ROM_CALL_155
.set	ams__ER_throwVar,			_ROM_CALL_153
.set	ams__find_error_message,		_ROM_CALL_2C1
.set	ams__EM_abandon,			_ROM_CALL_15B
.set	ams__EM_findEmptySlot,			_ROM_CALL_15F
.set	ams__EM_GC,				_ROM_CALL_160
.set	ams__EM_survey,				_ROM_CALL_165
.set	ams__EM_write,				_ROM_CALL_167
.set	ams__FL_addCert,			_ROM_CALL_169
.set	ams__FL_download,			_ROM_CALL_16A
.set	ams__FL_getCert,			_ROM_CALL_16C
.set	ams__FL_getHardwareParmBlock,		_ROM_CALL_16B
.set	ams__FL_getVerNum,			_ROM_CALL_16D
.set	ams__FL_write,				_ROM_CALL_171
.set	ams__BatTooLowFlash,			_ROM_CALL_434
.set	ams__FlashMemoryEnd,			_ROM_CALL_43D
.set	ams__EM_blockVerifyErase,		_ROM_CALL_15D
.set	ams__getcalc,				_ROM_CALL_54
.set	ams__LIO_Get,				_ROM_CALL_57
.set	ams__LIO_GetMultiple,			_ROM_CALL_59
.set	ams__LIO_Receive,			_ROM_CALL_58
.set	ams__LIO_RecvData,			_ROM_CALL_5B
.set	ams__LIO_Send,				_ROM_CALL_56
.set	ams__LIO_SendData,			_ROM_CALL_5A
.set	ams__LIO_SendProduct,			_ROM_CALL_253
.set	ams__OSCheckSilentLink,			_ROM_CALL_24A
.set	ams__OSLinkClose,			_ROM_CALL_24E
.set	ams__OSLinkCmd,				_ROM_CALL_24B
.set	ams__OSLinkOpen,			_ROM_CALL_24D
.set	ams__OSLinkReset,			_ROM_CALL_24C
.set	ams__OSLinkTxQueueActive,		_ROM_CALL_252
.set	ams__OSLinkTxQueueInquire,		_ROM_CALL_251
.set	ams__OSReadLinkBlock,			_ROM_CALL_24F
.set	ams__OSWriteLinkBlock,			_ROM_CALL_250
.set	ams__sendcalc,				_ROM_CALL_55
.set	ams__MenuAddIcon,			_ROM_CALL_42
.set	ams__MenuAddText,			_ROM_CALL_41
.set	ams__MenuBegin,				_ROM_CALL_36
.set	ams__MenuCheck,				_ROM_CALL_37
.set	ams__MenuEnd,				_ROM_CALL_38
.set	ams__MenuGetTopRedef,			_ROM_CALL_40
.set	ams__MenuKey,				_ROM_CALL_39
.set	ams__MenuNew,				_ROM_CALL_43
.set	ams__MenuOn,				_ROM_CALL_3A
.set	ams__MenuPopup,				_ROM_CALL_3B
.set	ams__MenuSubStat,			_ROM_CALL_3C
.set	ams__MenuTopRedef,			_ROM_CALL_3F
.set	ams__MenuTopSelect,			_ROM_CALL_3E
.set	ams__MenuTopStat,			_ROM_CALL_3D
.set	ams__MenuUpdate,			_ROM_CALL_49
.set	ams__PopupAddText,			_ROM_CALL_44
.set	ams__PopupClear,			_ROM_CALL_46
.set	ams__PopupDo,				_ROM_CALL_47
.set	ams__PopupNew,				_ROM_CALL_45
.set	ams__PopupText,				_ROM_CALL_48
.set	ams__VarCreateFolderPopup,		_ROM_CALL_28F
.set	ams__MenuLoad,				_ROM_CALL_3F2
.set	ams__MenuFlags,				_ROM_CALL_3F4
.set	ams__QMenuTopSelect,			_ROM_CALL_41A
.set	ams__DynMenuAdd,			_ROM_CALL_3F1
.set	ams__FKeyI_H,				_ROM_CALL_592
.set	ams__DynMenuChange,			_ROM_CALL_3F0
.set	ams__MenuItemDef,			_ROM_CALL_3F3
.set	ams__MenuOff,				_ROM_CALL_419
.set	ams__PopupBegin,			_ROM_CALL_3F5
.set	ams__PopupBeginDo,			_ROM_CALL_3F6
.set	ams__ceof,				_ROM_CALL_128
.set	ams__cfindfield,			_ROM_CALL_12A
.set	ams__cgetc,				_ROM_CALL_12B
.set	ams__cgetcertrevno,			_ROM_CALL_2A0
.set	ams__cgetflen,				_ROM_CALL_12D
.set	ams__cgetfnl,				_ROM_CALL_12E
.set	ams__cgetnl,				_ROM_CALL_12F
.set	ams__cgetns,				_ROM_CALL_130
.set	ams__cgetsn,				_ROM_CALL_2A1
.set	ams__copen,				_ROM_CALL_132
.set	ams__copensub,				_ROM_CALL_133
.set	ams__cputhdr,				_ROM_CALL_134
.set	ams__cputnl,				_ROM_CALL_135
.set	ams__cputns,				_ROM_CALL_136
.set	ams__cread,				_ROM_CALL_137
.set	ams__ctell,				_ROM_CALL_138
.set	ams__cwrite,				_ROM_CALL_139
.set	ams__CertificateMemory,			_ROM_CALL_43E
.set	ams__sprintf,				_ROM_CALL_53
.set	ams__cmd_clrdraw,			_ROM_CALL_32D
.set	ams__cmd_clrgraph,			_ROM_CALL_32F
.set	ams__cmd_clrhome,			_ROM_CALL_330
.set	ams__cmd_clrio,				_ROM_CALL_331
.set	ams__cmd_clrtable,			_ROM_CALL_332
.set	ams__cmd_custmoff,			_ROM_CALL_335
.set	ams__cmd_custmon,			_ROM_CALL_336
.set	ams__cmd_disp,				_ROM_CALL_33D
.set	ams__cmd_dispg,				_ROM_CALL_33E
.set	ams__cmd_disphome,			_ROM_CALL_33F
.set	ams__cmd_disptbl,			_ROM_CALL_340
.set	ams__cmd_fnoff,				_ROM_CALL_34D
.set	ams__cmd_fnon,				_ROM_CALL_34E
.set	ams__cmd_get,				_ROM_CALL_350
.set	ams__cmd_getcalc,			_ROM_CALL_351
.set	ams__cmd_graph,				_ROM_CALL_353
.set	ams__cmd_input,				_ROM_CALL_356
.set	ams__cmd_inputstr,			_ROM_CALL_357
.set	ams__cmd_newprob,			_ROM_CALL_367
.set	ams__cmd_output,			_ROM_CALL_369
.set	ams__cmd_pause,				_ROM_CALL_36B
.set	ams__cmd_printobj,			_ROM_CALL_370
.set	ams__cmd_prompt,			_ROM_CALL_371
.set	ams__cmd_rclgdb,			_ROM_CALL_381
.set	ams__cmd_send,				_ROM_CALL_387
.set	ams__cmd_sendcalc,			_ROM_CALL_388
.set	ams__cmd_sendchat,			_ROM_CALL_389
.set	ams__cmd_stogdb,			_ROM_CALL_390
.set	ams__cmd_style,				_ROM_CALL_392
.set	ams__cmd_table,				_ROM_CALL_393
.set	ams__cmd_shade,				_ROM_CALL_38A
.set	ams__cmd_newpic,			_ROM_CALL_365
.set	ams__cmd_newplot,			_ROM_CALL_366
.set	ams__cmd_pxlon,				_ROM_CALL_37B
.set	ams__cmd_circle,			_ROM_CALL_32C
.set	ams__cmd_cyclepic,			_ROM_CALL_339
.set	ams__cmd_randseed,			_ROM_CALL_380
.set	ams__cmd_line,				_ROM_CALL_358
.set	ams__cmd_andpic,			_ROM_CALL_32A
.set	ams__cmd_blddata,			_ROM_CALL_32B
.set	ams__cmd_clrerr,			_ROM_CALL_32E
.set	ams__cmd_drawparm,			_ROM_CALL_343
.set	ams__cmd_exit,				_ROM_CALL_34A
.set	ams__cmd_copyvar,			_ROM_CALL_333
.set	ams__cmd_cubicreg,			_ROM_CALL_334
.set	ams__cmd_custom,			_ROM_CALL_337
.set	ams__cmd_cycle,				_ROM_CALL_338
.set	ams__cmd_drawpol,			_ROM_CALL_344
.set	ams__cmd_delfold,			_ROM_CALL_33A
.set	ams__cmd_delvar,			_ROM_CALL_33B
.set	ams__cmd_dialog,			_ROM_CALL_33C
.set	ams__cmd_drawinv,			_ROM_CALL_342
.set	ams__cmd_drawfunc,			_ROM_CALL_341
.set	ams__cmd_linehorz,			_ROM_CALL_359
.set	ams__cmd_linetan,			_ROM_CALL_35A
.set	ams__cmd_else,				_ROM_CALL_345
.set	ams__cmd_endfor,			_ROM_CALL_346
.set	ams__cmd_for,				_ROM_CALL_34F
.set	ams__cmd_if,				_ROM_CALL_354
.set	ams__cmd_ifthen,			_ROM_CALL_355
.set	ams__cmd_linreg,			_ROM_CALL_35C
.set	ams__cmd_expreg,			_ROM_CALL_34B
.set	ams__cmd_lnreg,				_ROM_CALL_35D
.set	ams__cmd_logistic,			_ROM_CALL_360
.set	ams__cmd_sinreg,			_ROM_CALL_38C
.set	ams__cmd_twovar,			_ROM_CALL_398
.set	ams__cmd_onevar,			_ROM_CALL_368
.set	ams__cmd_showstat,			_ROM_CALL_38B
.set	ams__cmd_rplcpic,			_ROM_CALL_386
.set	ams__cmd_xorpic,			_ROM_CALL_39B
.set	ams__cmd_rclpic,			_ROM_CALL_382
.set	ams__cmd_pxlcircle,			_ROM_CALL_377
.set	ams__cmd_stopic,			_ROM_CALL_391
.set	ams__cmd_fill,				_ROM_CALL_34C
.set	ams__cmd_goto,				_ROM_CALL_352
.set	ams__cmd_popup,				_ROM_CALL_36E
.set	ams__cmd_endloop,			_ROM_CALL_347
.set	ams__cmd_endwhile,			_ROM_CALL_349
.set	ams__cmd_while,				_ROM_CALL_39A
.set	ams__cmd_try,				_ROM_CALL_397
.set	ams__cmd_endtry,			_ROM_CALL_348
.set	ams__cmd_passerr,			_ROM_CALL_36A
.set	ams__cmd_linevert,			_ROM_CALL_35B
.set	ams__cmd_plotsoff,			_ROM_CALL_36C
.set	ams__cmd_plotson,			_ROM_CALL_36D
.set	ams__cmd_slpline,			_ROM_CALL_38D
.set	ams__cmd_sortd,				_ROM_CALL_38F
.set	ams__cmd_sorta,				_ROM_CALL_38E
.set	ams__cmd_unlock,			_ROM_CALL_399
.set	ams__cmd_lock,				_ROM_CALL_35F
.set	ams__cmd_unarchiv,			_ROM_CALL_449
.set	ams__cmd_archive,			_ROM_CALL_448
.set	ams__cmd_pxlline,			_ROM_CALL_379
.set	ams__cmd_pxlhorz,			_ROM_CALL_378
.set	ams__cmd_pxlvert,			_ROM_CALL_37D
.set	ams__cmd_ptchg,				_ROM_CALL_372
.set	ams__cmd_ptoff,				_ROM_CALL_373
.set	ams__cmd_pxltext,			_ROM_CALL_37C
.set	ams__cmd_pton,				_ROM_CALL_374
.set	ams__cmd_pxlchg,			_ROM_CALL_376
.set	ams__cmd_pxloff,			_ROM_CALL_37A
.set	ams__cmd_text,				_ROM_CALL_394
.set	ams__cmd_pttext,			_ROM_CALL_375
.set	ams__cmd_local,				_ROM_CALL_35E
.set	ams__cmd_movevar,			_ROM_CALL_362
.set	ams__cmd_rename,			_ROM_CALL_383
.set	ams__cmd_return,			_ROM_CALL_385
.set	ams__cmd_trace,				_ROM_CALL_396
.set	ams__cmd_toolbar,			_ROM_CALL_395
.set	ams__cmd_request,			_ROM_CALL_384
.set	ams__cmd_newdata,			_ROM_CALL_363
.set	ams__cmd_newfold,			_ROM_CALL_364
.set	ams__cmd_zoomin,			_ROM_CALL_3A0
.set	ams__cmd_zoomdata,			_ROM_CALL_39D
.set	ams__cmd_zoomdec,			_ROM_CALL_39E
.set	ams__cmd_zoomfit,			_ROM_CALL_39F
.set	ams__cmd_zoomint,			_ROM_CALL_3A1
.set	ams__cmd_zoomprev,			_ROM_CALL_3A3
.set	ams__cmd_zoombox,			_ROM_CALL_39C
.set	ams__cmd_zoomout,			_ROM_CALL_3A2
.set	ams__cmd_zoomrcl,			_ROM_CALL_3A4
.set	ams__cmd_zoomsqr,			_ROM_CALL_3A5
.set	ams__cmd_zoomsto,			_ROM_CALL_3A7
.set	ams__cmd_zoomtrig,			_ROM_CALL_3A8
.set	ams__cmd_zoomstd,			_ROM_CALL_3A6
.set	ams__cmd_medmed,			_ROM_CALL_361
.set	ams__cmd_quartreg,			_ROM_CALL_37F
.set	ams__cmd_quadreg,			_ROM_CALL_37E
.set	ams__cmd_powerreg,			_ROM_CALL_36F
.set	ams__TE_checkSlack,			_ROM_CALL_A6
.set	ams__TE_close,				_ROM_CALL_A5
.set	ams__TE_empty,				_ROM_CALL_A7
.set	ams__TE_focus,				_ROM_CALL_A8
.set	ams__TE_handleEvent,			_ROM_CALL_A9
.set	ams__TE_indicateReadOnly,		_ROM_CALL_AA
.set	ams__TE_isBlank,			_ROM_CALL_AB
.set	ams__TE_openFixed,			_ROM_CALL_AD
.set	ams__TE_open,				_ROM_CALL_AC
.set	ams__TE_pasteText,			_ROM_CALL_AE
.set	ams__TE_reopenPlain,			_ROM_CALL_B0
.set	ams__TE_reopen,				_ROM_CALL_AF
.set	ams__TE_select,				_ROM_CALL_B1
.set	ams__TE_shrinkWrap,			_ROM_CALL_B2
.set	ams__TE_unfocus,			_ROM_CALL_B3
.set	ams__TE_updateCommand,			_ROM_CALL_B4
.set	ams__longjmp,				_ROM_CALL_267
.set	ams__setjmp,				_ROM_CALL_266
.set	ams__strcat,				_ROM_CALL_26E
.set	ams__strchr,				_ROM_CALL_274
.set	ams__strcmp,				_ROM_CALL_271
.set	ams__strcpy,				_ROM_CALL_26C
.set	ams__strcspn,				_ROM_CALL_275
.set	ams__strerror,				_ROM_CALL_27D
.set	ams__strlen,				_ROM_CALL_27E
.set	ams__strncat,				_ROM_CALL_26F
.set	ams__strncmp,				_ROM_CALL_272
.set	ams__strncpy,				_ROM_CALL_26D
.set	ams__strpbrk,				_ROM_CALL_276
.set	ams__strrchr,				_ROM_CALL_277
.set	ams__strspn,				_ROM_CALL_278
.set	ams__strstr,				_ROM_CALL_279
.set	ams__strtok,				_ROM_CALL_27A
.set	ams__cmpstri,				_ROM_CALL_16F
.set	ams__stricmp,				_ROM_CALL_407
.set	ams__memucmp,				_ROM_CALL_3CC
.set	ams__memcpy,				_ROM_CALL_26A
.set	ams__memchr,				_ROM_CALL_273
.set	ams__memcmp,				_ROM_CALL_270
.set	ams___memset,				_ROM_CALL_27B
.set	ams__memmove,				_ROM_CALL_26B
.set	ams__memset,				_ROM_CALL_27C
.set	ams__push_gcd_then_cofactors,		_ROM_CALL_59E
.set	ams__are_units_consistent,		_ROM_CALL_40F
.set	ams__assign_between,			_ROM_CALL_2AC
.set	ams__push_mrow_aux,			_ROM_CALL_31B
.set	ams__CharNumber,			_ROM_CALL_113
.set	ams__CheckGraphRef,			_ROM_CALL_7D
.set	ams__ST_flags,				_ROM_CALL_443
.set	ams__ck_valid_float,			_ROM_CALL_1E5
.set	ams___bcd_math,				_ROM_CALL_B5
.set	ams__cleanup_de_mem,			_ROM_CALL_1EC
.set	ams__cleanup_seq_mem,			_ROM_CALL_1D7
.set	ams__clear_error_context,		_ROM_CALL_44C
.set	ams__compare_numbers,			_ROM_CALL_50D
.set	ams__convert_to_TI_92,			_ROM_CALL_258
.set	ams__CountGrFunc,			_ROM_CALL_1D5
.set	ams__cpt_gr_fun,			_ROM_CALL_1D1
.set	ams__cpt_gr_param,			_ROM_CALL_1D2
.set	ams__cpt_gr_polar,			_ROM_CALL_1D3
.set	ams__GT_ValidGraphRanges,		_ROM_CALL_222
.set	ams__CptFuncX,				_ROM_CALL_1B9
.set	ams__CptIndep,				_ROM_CALL_1C9
.set	ams__CptLastIndepDE,			_ROM_CALL_1EF
.set	ams__CreateEmptyList,			_ROM_CALL_1E6
.set	ams__CTypeTable,			_ROM_CALL_442
.set	ams__CustomBegin,			_ROM_CALL_14A
.set	ams__CustomEnd,				_ROM_CALL_14C
.set	ams__CustomFree,			_ROM_CALL_150
.set	ams__CustomMenuItem,			_ROM_CALL_14B
.set	ams__DataTypeNames,			_ROM_CALL_43B
.set	ams__de_initRes,			_ROM_CALL_1F0
.set	ams__de_loop,				_ROM_CALL_1EB
.set	ams__de_rng_no_graph,			_ROM_CALL_2A2
.set	ams__delete_list_element,		_ROM_CALL_2AF
.set	ams__deStepCk,				_ROM_CALL_1F9
.set	ams__did_push_divide_units,		_ROM_CALL_3AE
.set	ams__did_push_lincf,			_ROM_CALL_572
.set	ams__did_push_var_val,			_ROM_CALL_2AD
.set	ams__divide_top,			_ROM_CALL_527
.set	ams__does_push_fetch,			_ROM_CALL_2AE
.set	ams__dv_create_graph_titles,		_ROM_CALL_117
.set	ams__dv_findColumn,			_ROM_CALL_119
.set	ams__TIOS_EV_getAppID,			_ROM_CALL_454
.set	ams__EQU_deStatus,			_ROM_CALL_16E
.set	ams__EQU_getNameInfo,			_ROM_CALL_120
.set	ams__EQU_select,			_ROM_CALL_11E
.set	ams__EQU_setStyle,			_ROM_CALL_11F
.set	ams__ER_throwFrame,			_ROM_CALL_507
.set	ams__ERD_dismissNotice,			_ROM_CALL_476
.set	ams__ERD_notice,			_ROM_CALL_475
.set	ams__estack_to_float,			_ROM_CALL_469
.set	ams__EV_appA,				_ROM_CALL_452
.set	ams__EV_appB,				_ROM_CALL_453
.set	ams__EV_appSide,			_ROM_CALL_458
.set	ams__EV_currentApp,			_ROM_CALL_45C
.set	ams__EV_errorCode,			_ROM_CALL_46D
.set	ams__TIOS_strtol,			_ROM_CALL_4FF
.set	ams__EV_quit,				_ROM_CALL_48E
.set	ams__EV_runningApp,			_ROM_CALL_45D
.set	ams__execute_graph_func,		_ROM_CALL_1D0
.set	ams__TokenizeName,			_ROM_CALL_3E9
.set	ams__GZ_Square,				_ROM_CALL_234
.set	ams__Regraph,				_ROM_CALL_1B6
.set	ams__gr_initCondName,			_ROM_CALL_1C8
.set	ams__grFuncName,			_ROM_CALL_1C7
.set	ams__GT_SaveAs,				_ROM_CALL_21C
.set	ams__GT_Open,				_ROM_CALL_21B
.set	ams__FindFunc,				_ROM_CALL_1C5
.set	ams__FindGrFunc,			_ROM_CALL_1C6
.set	ams__FirstNonblank,			_ROM_CALL_4DE
.set	ams__FirstSeqPlot,			_ROM_CALL_1D6
.set	ams__fix_loop_displacements,		_ROM_CALL_170
.set	ams__FLOATTAB,				_ROM_CALL_464
.set	ams__ForceFloat,			_ROM_CALL_47D
.set	ams__gen_version,			_ROM_CALL_259
.set	ams__freeIdList,			_ROM_CALL_4D6
.set	ams__gr_DelFolder,			_ROM_CALL_1CC
.set	ams__FuncLineFlt,			_ROM_CALL_1BF
.set	ams__GetStatValue,			_ROM_CALL_11B
.set	ams__GetSysGraphRef,			_ROM_CALL_8A
.set	ams__GM_Derivative,			_ROM_CALL_1B0
.set	ams__GM_DistArc,			_ROM_CALL_1B1
.set	ams__get_lb,				_ROM_CALL_516
.set	ams__get_list_indices,			_ROM_CALL_2B8
.set	ams__get_matrix_indices,		_ROM_CALL_2B9
.set	ams__get_ub,				_ROM_CALL_517
.set	ams__GM_Inflection,			_ROM_CALL_1AD
.set	ams__GM_Integrate,			_ROM_CALL_1AC
.set	ams__GetTagStr,				_ROM_CALL_46C
.set	ams__GM_Intersect,			_ROM_CALL_1AB
.set	ams__GM_Math1,				_ROM_CALL_1AF
.set	ams__GM_Shade,				_ROM_CALL_1B2
.set	ams__GM_TanLine,			_ROM_CALL_1AE
.set	ams__GM_Value,				_ROM_CALL_1AA
.set	ams__gr_add_fldpic,			_ROM_CALL_1F6
.set	ams__gr_ck_solvergraph,			_ROM_CALL_1FA
.set	ams__gr_CptIndepInc,			_ROM_CALL_1CA
.set	ams__gr_de_value,			_ROM_CALL_1ED
.set	ams__gr_del_locals,			_ROM_CALL_1CB
.set	ams__gr_del_vars_in_folder,		_ROM_CALL_1F1
.set	ams__gr_DispLabels,			_ROM_CALL_1E3
.set	ams__GR_Pan,				_ROM_CALL_1C4
.set	ams__gr_de_axes_lbl,			_ROM_CALL_1F2
.set	ams__gr_execute_de,			_ROM_CALL_1F3
.set	ams__gr_execute_seq,			_ROM_CALL_1D4
.set	ams__gr_find_de_result,			_ROM_CALL_1E8
.set	ams__gr_delete_fldpic,			_ROM_CALL_1F4
.set	ams__gr_seq_value,			_ROM_CALL_1DC
.set	ams__gr_stopic,				_ROM_CALL_1F7
.set	ams__gr_xres_pixel,			_ROM_CALL_1B8
.set	ams__GR3_addContours,			_ROM_CALL_1FB
.set	ams__GR3_handleEvent,			_ROM_CALL_1FE
.set	ams__gr_find_el,			_ROM_CALL_1F8
.set	ams__gr_find_func_index,		_ROM_CALL_1EE
.set	ams__GraphActivate,			_ROM_CALL_1FC
.set	ams__GrLineFlt,				_ROM_CALL_1BE
.set	ams__gr_openFolder,			_ROM_CALL_1CD
.set	ams__GraphOrTableCmd,			_ROM_CALL_1E4
.set	ams__gr_remove_fldpic,			_ROM_CALL_1F5
.set	ams__GS_PlotAll,			_ROM_CALL_202
.set	ams__GS_PlotTrace,			_ROM_CALL_201
.set	ams__GT_BackupToScr,			_ROM_CALL_20C
.set	ams__GT_DspMsg,				_ROM_CALL_212
.set	ams__GR3_freeDB,			_ROM_CALL_1FD
.set	ams__GT_CalcDepVals,			_ROM_CALL_20D
.set	ams__GT_Format,				_ROM_CALL_214
.set	ams__GT_CenterGraphCursor,		_ROM_CALL_20E
.set	ams__GT_CursorKey,			_ROM_CALL_20F
.set	ams__GrAxes,				_ROM_CALL_1B7
.set	ams__GrClipLine,			_ROM_CALL_1C0
.set	ams__GT_DE_Init_Conds,			_ROM_CALL_22A
.set	ams__GT_DspFreeTraceCoords,		_ROM_CALL_210
.set	ams__GT_DspTraceCoords,			_ROM_CALL_211
.set	ams__GT_FreeTrace,			_ROM_CALL_215
.set	ams__GT_IncXY,				_ROM_CALL_216
.set	ams__GT_KeyIn,				_ROM_CALL_217
.set	ams__GT_QFloatCursorsInRange,		_ROM_CALL_218
.set	ams__GT_Regraph,			_ROM_CALL_219
.set	ams__GT_Regraph_if_neccy,		_ROM_CALL_21A
.set	ams__GT_SelFunc,			_ROM_CALL_21D
.set	ams___du32u32,				_ROM_CALL_2AA
.set	ams__GT_Set_Graph_Format,		_ROM_CALL_228
.set	ams__GT_Error,				_ROM_CALL_213
.set	ams__GT_SetCursorXY,			_ROM_CALL_21F
.set	ams__GT_SetGraphRange,			_ROM_CALL_21E
.set	ams__GT_ShowMarkers,			_ROM_CALL_220
.set	ams__GT_Trace,				_ROM_CALL_221
.set	ams__GT_PrintCursor,			_ROM_CALL_229
.set	ams__GT_WinBound,			_ROM_CALL_223
.set	ams__GT_WinCursor,			_ROM_CALL_224
.set	ams__GZ_Decimal,			_ROM_CALL_22D
.set	ams__GZ_Fit,				_ROM_CALL_22E
.set	ams__GZ_InOut,				_ROM_CALL_22F
.set	ams__GZ_Integer,			_ROM_CALL_230
.set	ams__GZ_Previous,			_ROM_CALL_231
.set	ams__GZ_Recall,				_ROM_CALL_232
.set	ams__GZ_Standard,			_ROM_CALL_235
.set	ams__GZ_Stat,				_ROM_CALL_236
.set	ams__GZ_Store,				_ROM_CALL_237
.set	ams__GZ_Trig,				_ROM_CALL_238
.set	ams__InitDEAxesRng,			_ROM_CALL_1E9
.set	ams__InitDEMem,				_ROM_CALL_1EA
.set	ams__InitTimeSeq,			_ROM_CALL_1D9
.set	ams__GXcoord,				_ROM_CALL_226
.set	ams__GYcoord,				_ROM_CALL_225
.set	ams__NG_setup_graph_fun,		_ROM_CALL_261
.set	ams__PlotDel,				_ROM_CALL_203
.set	ams__PlotPut,				_ROM_CALL_204
.set	ams__QActivePlots,			_ROM_CALL_20A
.set	ams__QPlotActive,			_ROM_CALL_20B
.set	ams__seqStepCk,				_ROM_CALL_1DE
.set	ams__GZ_SetFactors,			_ROM_CALL_233
.set	ams__seqWebInit,			_ROM_CALL_1DA
.set	ams__SetGraphMode,			_ROM_CALL_1B5
.set	ams__setup_more_graph_fun,		_ROM_CALL_1CE
.set	ams__statFree,				_ROM_CALL_40A
.set	ams__has_different_variable,		_ROM_CALL_5A0
.set	ams__has_unit_base,			_ROM_CALL_3AF
.set	ams__hStrAppend,			_ROM_CALL_45F
.set	ams__index_after_match_endtag,		_ROM_CALL_2B1
.set	ams__index_if_pushed_binomial_info,	_ROM_CALL_5A1
.set	ams__index_if_pushed_qquad_info,	_ROM_CALL_5A2
.set	ams__index_reductum_with_tag_base,	_ROM_CALL_59F
.set	ams__index_rmng_factor,			_ROM_CALL_565
.set	ams__index_rmng_fctrs_start_base,	_ROM_CALL_564
.set	ams__index_rmng_fctrs_start_base_tag,	_ROM_CALL_563
.set	ams__index_rmng_fctrs_start_fctr_tag,	_ROM_CALL_562
.set	ams__init_list_indices,			_ROM_CALL_2BA
.set	ams__init_matrix_indices,		_ROM_CALL_2BB
.set	ams__init_unit_system,			_ROM_CALL_3B0
.set	ams__spike_chk_gr_dirty,		_ROM_CALL_11A
.set	ams__spike_in_editor,			_ROM_CALL_116
.set	ams__time_loop,				_ROM_CALL_1D8
.set	ams__is_cFloat_agg,			_ROM_CALL_465
.set	ams__is_complex_Float,			_ROM_CALL_48B
.set	ams__is_equivalent_to,			_ROM_CALL_578
.set	ams__is_executable,			_ROM_CALL_25A
.set	ams__is_neg_lead_numr_coef_re_part,	_ROM_CALL_56D
.set	ams__is_pathname,			_ROM_CALL_3C6
.set	ams__is_pos_int_and_eq_quantum,		_ROM_CALL_509
.set	ams__is_reciprocal_of_quantum,		_ROM_CALL_50A
.set	ams__is_term_improper,			_ROM_CALL_556
.set	ams__is_units_term,			_ROM_CALL_3B1
.set	ams__lead_conjunct_factor_index,	_ROM_CALL_580
.set	ams__lead_disjunct_term_index,		_ROM_CALL_57E
.set	ams__linear_degree,			_ROM_CALL_571
.set	ams__LIO_SendIdList,			_ROM_CALL_3D0
.set	ams__LoadSymFromFindHandle,		_ROM_CALL_281
.set	ams__LOC_formatDate,			_ROM_CALL_590
.set	ams__LOC_getLocalDateFormat,		_ROM_CALL_58F
.set	ams__LOC_localVersionDate,		_ROM_CALL_591
.set	ams__YCvtFtoP,				_ROM_CALL_1BC
.set	ams__next_token,			_ROM_CALL_3C7
.set	ams__next_var_or_kernel_index,		_ROM_CALL_56E
.set	ams__NG_control,			_ROM_CALL_466
.set	ams__nonblank,				_ROM_CALL_3C8
.set	ams__OO_appGetPublicStorage,		_ROM_CALL_425
.set	ams__OO_appIsMarkedDelete,		_ROM_CALL_426
.set	ams__OO_appMarkDelete,			_ROM_CALL_427
.set	ams__OO_AppNameToACB,			_ROM_CALL_406
.set	ams__OO_appSetPublicStorage,		_ROM_CALL_429
.set	ams__OO_Deref,				_ROM_CALL_3FB
.set	ams__TIOS_ldiv,				_ROM_CALL_5BD
.set	ams__OO_CondGetAttr,			_ROM_CALL_3FA
.set	ams__OO_Destroy,			_ROM_CALL_423
.set	ams__OO_DestroyAll,			_ROM_CALL_4F5
.set	ams__OO_firstACB,			_ROM_CALL_451
.set	ams__OO_GetAppAttr,			_ROM_CALL_3FC
.set	ams__OO_GetAttr,			_ROM_CALL_3FD
.set	ams__OO_HasAttr,			_ROM_CALL_3FE
.set	ams__OO_InstallAppHook,			_ROM_CALL_490
.set	ams__OO_InstallAppHookByName,		_ROM_CALL_492
.set	ams__OO_InstallSystemHook,		_ROM_CALL_404
.set	ams__OO_New,				_ROM_CALL_3FF
.set	ams__OO_NextACB,			_ROM_CALL_402
.set	ams__OO_PrevACB,			_ROM_CALL_403
.set	ams__OO_SetAppAttr,			_ROM_CALL_400
.set	ams__OO_SetAttr,			_ROM_CALL_401
.set	ams__OO_SuperFrame,			_ROM_CALL_48F
.set	ams__OO_UninstallAppHook,		_ROM_CALL_491
.set	ams__OO_UninstallAppHookByName,		_ROM_CALL_493
.set	ams__OO_UninstallSystemHook,		_ROM_CALL_405
.set	ams__or_onto_top,			_ROM_CALL_57B
.set	ams__OSModKeyStatus,			_ROM_CALL_431
.set	ams__paint_all_except,			_ROM_CALL_11D
.set	ams__ParseSymName,			_ROM_CALL_78
.set	ams__PlotDup,				_ROM_CALL_207
.set	ams__PlotGet,				_ROM_CALL_205
.set	ams__PlotInit,				_ROM_CALL_206
.set	ams__PlotLookup,			_ROM_CALL_209
.set	ams__PlotSize,				_ROM_CALL_208
.set	ams__primary_tag_list,			_ROM_CALL_467
.set	ams__pSymPG,				_ROM_CALL_430
.set	ams__push_ans_entry,			_ROM_CALL_2B0
.set	ams__push_auto_units_conversion,	_ROM_CALL_3B2
.set	ams__push_but_conjunct_factor,		_ROM_CALL_582
.set	ams__push_but_factor,			_ROM_CALL_561
.set	ams__push_but_term,			_ROM_CALL_56A
.set	ams__push_constant_factors,		_ROM_CALL_55D
.set	ams__push_constant_terms,		_ROM_CALL_566
.set	ams__push_dependent_factors,		_ROM_CALL_55F
.set	ams__push_dependent_terms,		_ROM_CALL_568
.set	ams__times_top,				_ROM_CALL_522
.set	ams__push_float_qr_fact,		_ROM_CALL_2BC
.set	ams__push_format,			_ROM_CALL_315
.set	ams__push_independent_factors,		_ROM_CALL_560
.set	ams__push_independent_terms,		_ROM_CALL_569
.set	ams__TIOS_abs,				_ROM_CALL_5BA
.set	ams__push_lu_fact,			_ROM_CALL_2BD
.set	ams__push_make_proper,			_ROM_CALL_557
.set	ams__push_minus_recip_of_quantum,	_ROM_CALL_510
.set	ams__push_negate_quantum_as_negint,	_ROM_CALL_4F1
.set	ams__push_nonconstant_factors,		_ROM_CALL_55E
.set	ams__push_nonconstant_terms,		_ROM_CALL_567
.set	ams__push_nonnumeric_factors,		_ROM_CALL_55C
.set	ams__push_parse_prgm_or_func_text,	_ROM_CALL_3C9
.set	ams__push_pi,				_ROM_CALL_512
.set	ams__push_pi_on_quantum,		_ROM_CALL_513
.set	ams__push_poly_deg_in_var_or_kernel,	_ROM_CALL_570
.set	ams__push_poly_qr,			_ROM_CALL_59D
.set	ams__push_quantum_as_nonnegative_int,	_ROM_CALL_50E
.set	ams__push_quantum_pair_as_pos_frac,	_ROM_CALL_511
.set	ams__push_reciprocal,			_ROM_CALL_597
.set	ams__push_reciprocal_of_quantum,	_ROM_CALL_50F
.set	ams__push_simplify_statements,		_ROM_CALL_44F
.set	ams__push_sq_matrix_to_whole_number,	_ROM_CALL_3C0
.set	ams__push_standardize,			_ROM_CALL_558
.set	ams__push_symbolic_qr_fact,		_ROM_CALL_2BE
.set	ams__push_trig,				_ROM_CALL_535
.set	ams__push_unit_system_list,		_ROM_CALL_3B3
.set	ams__push_var,				_ROM_CALL_3CB
.set	ams__push_var_kern_tail,		_ROM_CALL_56F
.set	ams__push_zero_partial_column,		_ROM_CALL_3C2
.set	ams__push0,				_ROM_CALL_4E7
.set	ams__push1,				_ROM_CALL_4E8
.set	ams__VarGraphRefBitsClear,		_ROM_CALL_268
.set	ams__YCvtFtoWin,			_ROM_CALL_1B3
.set	ams__QSkipGraphErr,			_ROM_CALL_1E7
.set	ams__QstatRcl,				_ROM_CALL_40B
.set	ams__raise_to_top,			_ROM_CALL_529
.set	ams__ReallocExprStruct,			_ROM_CALL_14D
.set	ams__recall_data_var,			_ROM_CALL_112
.set	ams__remaining_conjuncts_index,		_ROM_CALL_581
.set	ams__remaining_disjuncts_index,		_ROM_CALL_57F
.set	ams__replace_top_with_reciprocal,	_ROM_CALL_52D
.set	ams__replace_top2_with_and,		_ROM_CALL_57A
.set	ams__replace_top2_with_difference,	_ROM_CALL_51C
.set	ams__replace_top2_with_imre,		_ROM_CALL_559
.set	ams__replace_top2_with_or,		_ROM_CALL_57C
.set	ams__replace_top2_with_pow,		_ROM_CALL_52A
.set	ams__replace_top2_with_prod,		_ROM_CALL_523
.set	ams__replace_top2_with_ratio,		_ROM_CALL_528
.set	ams__replace_top2_with_sum,		_ROM_CALL_519
.set	ams__run_one_seq,			_ROM_CALL_1DB
.set	ams__ScrRectDivide,			_ROM_CALL_28
.set	ams__SearchExprStruct,			_ROM_CALL_14E
.set	ams__setup_unit_system,			_ROM_CALL_3B4
.set	ams__sf_width,				_ROM_CALL_4D3
.set	ams__SP_Define,				_ROM_CALL_110
.set	ams__spike_geo_titles,			_ROM_CALL_115
.set	ams__spike_optionD,			_ROM_CALL_114
.set	ams__spike_titles_in_editor,		_ROM_CALL_118
.set	ams__statEnd,				_ROM_CALL_409
.set	ams__statStart,				_ROM_CALL_408
.set	ams___ds32s32,				_ROM_CALL_2A8
.set	ams__store_data_var,			_ROM_CALL_111
.set	ams__store_func_def,			_ROM_CALL_2B4
.set	ams__store_to_subscripted_element,	_ROM_CALL_2B5
.set	ams___du16u16,				_ROM_CALL_2A6
.set	ams__tokenize_if_TI_92_or_text,		_ROM_CALL_265
.set	ams__unlock_more_graph_fun,		_ROM_CALL_1CF
.set	ams__ValidateStore,			_ROM_CALL_8D
.set	ams__VarOptList,			_ROM_CALL_444
.set	ams__VarSaveTitle,			_ROM_CALL_290
.set	ams__VarStoreLink,			_ROM_CALL_87
.set	ams__WinBeginPaint,			_ROM_CALL_500
.set	ams__WinBitmapSizeExt,			_ROM_CALL_411
.set	ams__WinEndPaint,			_ROM_CALL_501
.set	ams__WinLineExt,			_ROM_CALL_47C
.set	ams__WinRemove,				_ROM_CALL_414
.set	ams__XCvtFtoP,				_ROM_CALL_1BD
.set	ams__XCvtPtoF,				_ROM_CALL_1BA
.set	ams___ms32s32,				_ROM_CALL_2A9
.set	ams__YCvtPtoF,				_ROM_CALL_1BB
.set	ams__did_map_aggregate_arg,		_ROM_CALL_5B8
.set	ams__did_push_approx_inflection_point,	_ROM_CALL_5B0
.set	ams__errno,				_ROM_CALL_5D9
.set	ams__estack_max_index,			_ROM_CALL_5BF
.set	ams__EV_flags,				_ROM_CALL_5DF
.set	ams__Float0Index,			_ROM_CALL_5D0
.set	ams__Float1Index,			_ROM_CALL_5D1
.set	ams__FloatExp1Index,			_ROM_CALL_5D4
.set	ams__FloatHalfIndex,			_ROM_CALL_5E0
.set	ams__FloatMinus1Index,			_ROM_CALL_5D2
.set	ams__FloatPiIndex,			_ROM_CALL_5D3
.set	ams__IM_re_tol,				_ROM_CALL_5C1
.set	ams__index_false,			_ROM_CALL_5D6
.set	ams__index_true,			_ROM_CALL_5D5
.set	ams__Integer0Index,			_ROM_CALL_5CD
.set	ams__Integer1Index,			_ROM_CALL_5CE
.set	ams__Integer2Index,			_ROM_CALL_5E1
.set	ams__IntegerMinus1Index,		_ROM_CALL_5CF
.set	ams__is_real,				_ROM_CALL_5A9
.set	ams__is_undefined,			_ROM_CALL_5B7
.set	ams__NG_such_that_index,		_ROM_CALL_5D7
.set	ams__OSCheckLinkOpen,			_ROM_CALL_5E3
.set	ams__RM_Type,				_ROM_CALL_5DC
.set	ams__TIOS_labs,				_ROM_CALL_5BC
.set	ams__RAtionalize_tol,			_ROM_CALL_5C0
.set	ams__replace_top_with_post_simplified,	_ROM_CALL_5B6
.set	ams__WinStrXYWrap,			_ROM_CALL_5DB
.set	ams__TIOS_div,				_ROM_CALL_5BB
.set	ams___mu32u32,				_ROM_CALL_2AB
.set	ams__UpdateWindows,			_ROM_CALL_2B
.set	ams__push_user_func,			_ROM_CALL_2B3
.set	ams___ds16u16,				_ROM_CALL_2A4
.set	ams___mu16u16,				_ROM_CALL_2A7
.set	ams__NG_cleanup_graph_fun,		_ROM_CALL_262
.set	ams___ms16u16,				_ROM_CALL_2A5
.set	ams__OSKeyScan,				_ROM_CALL_298
.set	ams__GD_HVLine,				_ROM_CALL_178
.set	ams__GD_Circle,				_ROM_CALL_176
.set	ams__GD_Pen,				_ROM_CALL_179
.set	ams__GD_Eraser,				_ROM_CALL_17A
.set	ams__GD_Text,				_ROM_CALL_17B
.set	ams__GD_Select,				_ROM_CALL_17C
.set	ams__GD_Contour,			_ROM_CALL_17D
.set	ams__GD_Line,				_ROM_CALL_177
.set	ams__GR3_paint3d,			_ROM_CALL_1FF
.set	ams__GR3_xyToWindow,			_ROM_CALL_200
.set	ams__GZ_Box,				_ROM_CALL_22B
.set	ams__GZ_Center,				_ROM_CALL_22C
.set	ams__HomeAlone,				_ROM_CALL_506
.set	ams__HS_getAns,				_ROM_CALL_241
.set	ams__HomeExecute,			_ROM_CALL_10E
.set	ams__HomePushEStack,			_ROM_CALL_10F
.set	ams__HS_getEntry,			_ROM_CALL_242
.set	ams__HS_countFIFO,			_ROM_CALL_23D
.set	ams__HS_freeFIFONode,			_ROM_CALL_240
.set	ams__HS_deleteFIFONode,			_ROM_CALL_23E
.set	ams__HS_freeAll,			_ROM_CALL_23F
.set	ams__HS_chopFIFO,			_ROM_CALL_23C
.set	ams__HS_getFIFONode,			_ROM_CALL_243
.set	ams__HS_newFIFONode,			_ROM_CALL_245
.set	ams__HS_pushFIFONode,			_ROM_CALL_246
.set	ams__HS_popEStack,			_ROM_CALL_244
.set	ams__push_matrix_product,		_ROM_CALL_3C5
.set	ams__push_list_times,			_ROM_CALL_3BE
.set	ams__push_list_plus,			_ROM_CALL_3BD
.set	ams__push_pow,				_ROM_CALL_30F
.set	ams__push_and,				_ROM_CALL_5AB
.set	ams__push_arg_plus_1,			_ROM_CALL_51F
.set	ams__push_arg_minus_1,			_ROM_CALL_520
.set	ams__push_assignment,			_ROM_CALL_4DD
.set	ams__push_difference,			_ROM_CALL_51A
.set	ams__push_dot_div,			_ROM_CALL_4CD
.set	ams__push_dot_add,			_ROM_CALL_4A0
.set	ams__push_dot_exponentiate,		_ROM_CALL_596
.set	ams__push_dot_mult,			_ROM_CALL_4A1
.set	ams__push_dot_sub,			_ROM_CALL_4A2
.set	ams__push_equals,			_ROM_CALL_5A3
.set	ams__push_exponentiate,			_ROM_CALL_595
.set	ams__push_to_sphere,			_ROM_CALL_329
.set	ams__push_factorial,			_ROM_CALL_540
.set	ams__push_greater_than,			_ROM_CALL_5A5
.set	ams__push_greater_than_or_equals,	_ROM_CALL_5A7
.set	ams__push_indir_name,			_ROM_CALL_2B2
.set	ams__push_degrees,			_ROM_CALL_314
.set	ams__push_less_than,			_ROM_CALL_5A6
.set	ams__push_less_than_or_equals,		_ROM_CALL_5A8
.set	ams__push_negate,			_ROM_CALL_524
.set	ams__push_not,				_ROM_CALL_5AA
.set	ams__push_not_equals,			_ROM_CALL_5A4
.set	ams__push_or,				_ROM_CALL_5AC
.set	ams__push_percent,			_ROM_CALL_555
.set	ams__push_radians,			_ROM_CALL_4B3
.set	ams__push_product,			_ROM_CALL_521
.set	ams__push_ratio,			_ROM_CALL_526
.set	ams__push_sum,				_ROM_CALL_594
.set	ams__push_substitute_simplify,		_ROM_CALL_5B9
.set	ams__push_substitute_using_such_that,	_ROM_CALL_5BE
.set	ams__push_substitute_no_simplify,	_ROM_CALL_489
.set	ams__push_to_cylin,			_ROM_CALL_328
.set	ams__did_push_to_polar,			_ROM_CALL_313
.set	ams__push_square,			_ROM_CALL_52C
.set	ams__push_setgraph,			_ROM_CALL_322
.set	ams__push_getmode,			_ROM_CALL_318
.set	ams__push_rand,				_ROM_CALL_31F
.set	ams__push_getkey,			_ROM_CALL_316
.set	ams__push_setmode,			_ROM_CALL_323
.set	ams__push_settable,			_ROM_CALL_324
.set	ams__push_switch,			_ROM_CALL_327
.set	ams__push_acos,				_ROM_CALL_537
.set	ams__push_abs,				_ROM_CALL_543
.set	ams__push_acosh,			_ROM_CALL_53E
.set	ams__push_1st_derivative,		_ROM_CALL_5AE
.set	ams__push_approx,			_ROM_CALL_4F7
.set	ams__push_asinh,			_ROM_CALL_53D
.set	ams__push_asin,				_ROM_CALL_536
.set	ams__push_augment,			_ROM_CALL_496
.set	ams__push_atanh,			_ROM_CALL_53F
.set	ams__push_atan,				_ROM_CALL_538
.set	ams__push_char,				_ROM_CALL_497
.set	ams__push_ceiling,			_ROM_CALL_54B
.set	ams__push_coldim,			_ROM_CALL_498
.set	ams__push_colnorm,			_ROM_CALL_499
.set	ams__push_comdenom,			_ROM_CALL_59B
.set	ams__push_conj,				_ROM_CALL_547
.set	ams__push_cosh,				_ROM_CALL_53B
.set	ams__push_cos,				_ROM_CALL_533
.set	ams__push_cross_product,		_ROM_CALL_4CE
.set	ams__push_cumsum,			_ROM_CALL_49A
.set	ams__push_csolve,			_ROM_CALL_585
.set	ams__push_czeros,			_ROM_CALL_587
.set	ams__push_def_int,			_ROM_CALL_5B2
.set	ams__push_desolve,			_ROM_CALL_58B
.set	ams__push_determinant,			_ROM_CALL_49D
.set	ams__push_diag,				_ROM_CALL_49E
.set	ams__push_dimension,			_ROM_CALL_49F
.set	ams__push_dotproduct,			_ROM_CALL_4A3
.set	ams__push_eigvc,			_ROM_CALL_4CF
.set	ams__push_eigvl,			_ROM_CALL_4D0
.set	ams__push_exp,				_ROM_CALL_52E
.set	ams__push_expand,			_ROM_CALL_59A
.set	ams__push_factor,			_ROM_CALL_59C
.set	ams__push_floor,			_ROM_CALL_54A
.set	ams__push_fractional_part,		_ROM_CALL_54E
.set	ams__push_gcd_numbers,			_ROM_CALL_514
.set	ams__push_randnorm,			_ROM_CALL_4B5
.set	ams__push_getfold,			_ROM_CALL_317
.set	ams__push_gettype,			_ROM_CALL_319
.set	ams__push_identity_mat,			_ROM_CALL_4A4
.set	ams__push_im,				_ROM_CALL_546
.set	ams__push_re,				_ROM_CALL_545
.set	ams__push_comb,				_ROM_CALL_542
.set	ams__push_perm,				_ROM_CALL_541
.set	ams__push_part,				_ROM_CALL_31C
.set	ams__push_instring,			_ROM_CALL_31A
.set	ams__push_integer_remainder,		_ROM_CALL_550
.set	ams__push_integer_part,			_ROM_CALL_54D
.set	ams__push_integer_gcd,			_ROM_CALL_551
.set	ams__push_integer_lcm,			_ROM_CALL_552
.set	ams__push_integer_quotient,		_ROM_CALL_54F
.set	ams__push_is_prime,			_ROM_CALL_515
.set	ams__push_left,				_ROM_CALL_4A5
.set	ams__did_push_series,			_ROM_CALL_588
.set	ams__push_lim,				_ROM_CALL_5AD
.set	ams__push_ln,				_ROM_CALL_52F
.set	ams__push_list_to_mat,			_ROM_CALL_4A6
.set	ams__push_log10,			_ROM_CALL_530
.set	ams__push_mat_to_list,			_ROM_CALL_4A8
.set	ams__push_matnorm,			_ROM_CALL_4A7
.set	ams__push_max,				_ROM_CALL_58A
.set	ams__push_median,			_ROM_CALL_4AA
.set	ams__push_mean,				_ROM_CALL_4A9
.set	ams__push_mid,				_ROM_CALL_4AB
.set	ams__push_min,				_ROM_CALL_589
.set	ams__push_mod,				_ROM_CALL_54C
.set	ams__push_mrow,				_ROM_CALL_4AC
.set	ams__did_push_anti_deriv,		_ROM_CALL_5B1
.set	ams__push_mrowadd,			_ROM_CALL_4AD
.set	ams__push_newmat,			_ROM_CALL_4AF
.set	ams__push_newlist,			_ROM_CALL_4AE
.set	ams__push_nint,				_ROM_CALL_5B3
.set	ams__push_nsolve,			_ROM_CALL_583
.set	ams__push_nth_derivative,		_ROM_CALL_5AF
.set	ams__push_denominator,			_ROM_CALL_55B
.set	ams__push_numerator,			_ROM_CALL_55A
.set	ams__push_max2,				_ROM_CALL_599
.set	ams__push_max1,				_ROM_CALL_554
.set	ams__push_min1,				_ROM_CALL_553
.set	ams__push_min2,				_ROM_CALL_598
.set	ams__push_ord,				_ROM_CALL_4B0
.set	ams__push_r_cis,			_ROM_CALL_549
.set	ams__push_pttest,			_ROM_CALL_31D
.set	ams__push_pxltest,			_ROM_CALL_31E
.set	ams__push_when,				_ROM_CALL_57D
.set	ams__push_zeros,			_ROM_CALL_586
.set	ams__push_prodlist,			_ROM_CALL_4B2
.set	ams__push_randmat,			_ROM_CALL_4B4
.set	ams__push_randpoly,			_ROM_CALL_320
.set	ams__push_right,			_ROM_CALL_4B7
.set	ams__push_rotate,			_ROM_CALL_4B8
.set	ams__push_round,			_ROM_CALL_4B9
.set	ams__push_row_echelon,			_ROM_CALL_4BE
.set	ams__push_red_row_ech,			_ROM_CALL_4B6
.set	ams__push_rowdim,			_ROM_CALL_4BB
.set	ams__push_rowadd,			_ROM_CALL_4BA
.set	ams__push_rowswap,			_ROM_CALL_4BD
.set	ams__push_rownorm,			_ROM_CALL_4BC
.set	ams__push_sequence,			_ROM_CALL_4BF
.set	ams__push_setfold,			_ROM_CALL_321
.set	ams__push_shift,			_ROM_CALL_4C0
.set	ams__push_sign,				_ROM_CALL_544
.set	ams__push_sin2,				_ROM_CALL_531
.set	ams__push_sin,				_ROM_CALL_532
.set	ams__push_simult,			_ROM_CALL_4C1
.set	ams__push_sinh,				_ROM_CALL_53A
.set	ams__push_solve,			_ROM_CALL_584
.set	ams__push_sqrt,				_ROM_CALL_52B
.set	ams__push_string,			_ROM_CALL_326
.set	ams__push_stddev,			_ROM_CALL_4C3
.set	ams__push_submat,			_ROM_CALL_4C4
.set	ams__push_str_to_expr,			_ROM_CALL_325
.set	ams__push_sumlist,			_ROM_CALL_4C5
.set	ams__push_summation,			_ROM_CALL_5B4
.set	ams__push_extended_prod,		_ROM_CALL_5B5
.set	ams__push_tan,				_ROM_CALL_534
.set	ams__push_tanh,				_ROM_CALL_53C
.set	ams__push_unitv,			_ROM_CALL_4C8
.set	ams__push_variance,			_ROM_CALL_4C9
.set	ams__push_rec_to_angle,			_ROM_CALL_539
.set	ams__push_phase,			_ROM_CALL_548
.set	ams__push_dense_poly_eval,		_ROM_CALL_49C
.set	ams__push_div_dif_1c,			_ROM_CALL_58D
.set	ams__push_div_dif_1f,			_ROM_CALL_58C
.set	ams__FCreate,				_ROM_CALL_3D6
.set	ams__FDelete,				_ROM_CALL_3D7
.set	ams__FEof,				_ROM_CALL_3D8
.set	ams__FFindNext,				_ROM_CALL_3DA
.set	ams__FGetC,				_ROM_CALL_3DB
.set	ams__FGetPos,				_ROM_CALL_3DC
.set	ams__FOpen,				_ROM_CALL_3DE
.set	ams__FRead,				_ROM_CALL_3E0
.set	ams__FSetBufSize,			_ROM_CALL_3E2
.set	ams__FSetPos,				_ROM_CALL_3E1
.set	ams__FSetVer,				_ROM_CALL_3E4
.set	ams__FStatus,				_ROM_CALL_3E5
.set	ams__FWrite,				_ROM_CALL_3E7
.set	ams__FFindFirst,			_ROM_CALL_3D9
.set	ams__FAccess,				_ROM_CALL_3D4
.set	ams__FClose,				_ROM_CALL_3D5
.set	ams__FGetSize,				_ROM_CALL_3DD
.set	ams__FPutC,				_ROM_CALL_3DF
.set	ams__FSetSize,				_ROM_CALL_3E3
.set	ams__FType,				_ROM_CALL_3E6
.set	ams__CkValidDelta,			_ROM_CALL_1C3
.set	ams__gr_active,				_ROM_CALL_10B
.set	ams__gr_flags,				_ROM_CALL_463
.set	ams__gr_other,				_ROM_CALL_10C
.set	ams__StepCk,				_ROM_CALL_1DD
.set	ams__CptDeltax,				_ROM_CALL_1C1
.set	ams__CptDeltay,				_ROM_CALL_1C2
.set	ams__gdb_len,				_ROM_CALL_1E0
.set	ams__gdb_recall,			_ROM_CALL_1E2
.set	ams__gdb_store,				_ROM_CALL_1E1
.set	ams__rngLen,				_ROM_CALL_1DF
.set	ams__NoCallBack,			_ROM_CALL_31
.set	ams__caddcert,				_ROM_CALL_126
.set	ams__cgetvernum,			_ROM_CALL_131
.set	ams__EM_writeToExtMem,			_ROM_CALL_168
.set	ams__OSVRegisterTimer,			_ROM_CALL_284
.set	ams__OSVFreeTimer,			_ROM_CALL_285

.set	ams__ScreenClear,			_ROM_CALL_19E
.set	ams__DrawStrXY,				_ROM_CALL_1A9
.set	ams__ArchiveErase,			_ROM_CALL_16A+0x10
.set	ams__ArchiveWrite,			_ROM_CALL_171
.set	ams__bcdadd,				_ROM_CALL_B6
.set	ams__bcdcmp,				_ROM_CALL_BB
.set	ams__bcddiv,				_ROM_CALL_B9
.set	ams__bcdbcd,				_ROM_CALL_BD
.set	ams__bcdmul,				_ROM_CALL_B8
.set	ams__bcdneg,				_ROM_CALL_BA
.set	ams__bcdsub,				_ROM_CALL_B7
.set	ams__bcdlong,				_ROM_CALL_BC

.set	ams__ST_showHelp,			_ROM_CALL_E6
.set	ams__DrawTo,				_ROM_CALL_19C
.set	ams__flush_link,			_ROM_CALL_24D
.set	ams__receive,				_ROM_CALL_24F
.set	ams__reset_link,			_ROM_CALL_24C
.set	ams__transmit,				_ROM_CALL_250
.set	ams__tx_free,				_ROM_CALL_252

.set	ams__SymFindFoldername,			_ROM_CALL_6F
.set	ams__MakeHsym,				_ROM_CALL_282

|===================================
|	ROM calls (not relocated)
|===================================
.set	acos,					0xF5
.set	acosh,					0x288
.set	asin,					0xF6
.set	asinh,					0x287
.set	atan,					0xF7
.set	atan2,					0xF8
.set	atanh,					0x289
.set	cacos,					0x13A
.set	cacosh,					0x13D
.set	casin,					0x13B
.set	casinh,					0x13E
.set	catan,					0x13C
.set	catanh,					0x13F
.set	ccos,					0x140
.set	ccosh,					0x143
.set	ceil,					0x105
.set	cexp,					0x149
.set	cln,					0x147
.set	clog10,					0x148
.set	cos,					0xF9
.set	cosh,					0xFC
.set	csin,					0x141
.set	csinh,					0x144
.set	csqrt,					0x146
.set	ctan,					0x142
.set	ctanh,					0x145
.set	exp,					0xFF
.set	fabs,					0x106
.set	fadd,					0xB6
.set	fcmp,					0xBB
.set	fdiv,					0xB9
.set	flt,					0xBD
.set	float_class,				0x2FA
.set	floor,					0x107
.set	fmod,					0x108
.set	fmul,					0xB8
.set	fneg,					0xBA
.set	fpisanint,				0x172
.set	fpisodd,				0x173
.set	frexp10,				0x2FB
.set	fsub,					0xB7
.set	is_float_infinity,			0x2FF
.set	is_float_negative_zero,			0x300
.set	is_float_positive_zero,			0x301
.set	is_float_signed_infinity,		0x302
.set	is_float_transfinite,			0x303
.set	is_float_unsigned_inf_or_nan,		0x304
.set	is_float_unsigned_zero,			0x305
.set	is_inf,					0x2FF
.set	is_nan,					0x306
.set	is_nzero,				0x300
.set	is_pzero,				0x301
.set	is_sinf,				0x302
.set	is_transfinite,				0x303
.set	is_uinf_or_nan,				0x304
.set	is_uzero,				0x305
.set	itrig,					0x28A
.set	log,					0x100
.set	log10,					0x101
.set	modf,					0x102
.set	pow,					0x103
.set	round12,				0x174
.set	round12_err,				0x227
.set	round14,				0x175
.set	sin,					0xFA
.set	sincos,					0x286
.set	sinh,					0xFD
.set	sqrt,					0x104
.set	tan,					0xFB
.set	tanh,					0xFE
.set	trig,					0x28B
.set	trunc,					0xBC
.set	all_tail,				0x3B5
.set	any_tail,				0x3B6
.set	are_expressions_identical,		0x2BF
.set	can_be_approxed,			0x2F5
.set	check_estack_size,			0x2C2
.set	compare_complex_magnitudes,	0x2F6
.set	compare_expressions,		0x2C0
.set	compare_Floats,			0x2F7
.set	deleted_between,			0x2C4
.set	deleted_expression,		0x2C6
.set	delete_between,			0x2C3
.set	delete_expression,			0x2C5
.set	did_push_cnvrt_Float_to_integer,	0x2F8
.set	display_statements,		0x4E
.set	estack_number_to_Float,		0x2F9
.set	estack_to_short,			0x2C7
.set	estack_to_ushort,			0x2C8
.set	factor_base_index,			0x2C9
.set	factor_exponent_index,		0x2CA
.set	gcd_exact_whole_Floats,		0x2FC
.set	GetValue,				0x2CB
.set	get_key_ptr,			0x2B7
.set	HToESI,				0x247
.set	im_index,				0x2CC
.set	index_below_display_expression_aux,	0x2B6
.set	index_main_var,			0x2CF
.set	index_numeric_term,		0x2CD
.set	index_of_lead_base_of_lead_term,	0x2CE
.set	is_advanced_tag,			0x2D0
.set	is_antisymmetric,			0x2D1
.set	is_complex_number,			0x2D2
.set	is_complex0,			0x2D3
.set	is_Float_exact_whole_number,	0x2FE
.set	is_free_of_tag,			0x2D4
.set	is_independent_of,			0x2D5
.set	is_independent_of_de_seq_vars,	0x2D6
.set	is_independent_of_elements,	0x2D8
.set	is_independent_of_tail,		0x2D7
.set	is_matrix,				0x3B7
.set	is_monomial,			0x2D9
.set	is_monomial_in_kernel,		0x2DA
.set	is_narrowly_independent_of,	0x2DB
.set	is_square_matrix,			0x3B8
.set	is_symmetric,			0x2DC
.set	bottom_estack,			0x432
.set	is_valid_smap_aggregate,		0x3B9
.set	last_element_index,		0x3BA
.set	lead_base_index,			0x2DE
.set	lead_exponent_index,		0x2DF
.set	lead_factor_index,			0x2E0
.set	lead_term_index,			0x2E1
.set	likely_approx_to_complex_number,	0x307
.set	likely_approx_to_number,		0x308
.set	main_gen_var_index,		0x2E2
.set	map_tail,				0x3BB
.set	map_tail_Int,			0x3BC
.set	map_unary_over_comparison,		0x2E3
.set	min_quantum,			0x2E4
.set	moved_between_to_top,		0x2E6
.set	move_between_to_top,		0x2E5
.set	next_expression_index,		0x10A
.set	NG_approxESI,			0x25C
.set	NG_execute,			0x25D
.set	NG_graphESI,			0x25E
.set	NG_rationalESI,			0x25F
.set	NG_RPNToText,			0x25B
.set	NG_tokenize,			0x260
.set	norm1_complex_Float,		0x309
.set	numeric_factor_index,		0x2E7
.set	Parms2D,				0x4D
.set	Parse1DExpr,			0x4F
.set	Parse2DExpr,			0x4A
.set	Parse2DMultiExpr,			0x4B
.set	Print2DExpr,			0x4C
.set	push_ANSI_string,			0x48A
.set	push_between,			0x2E8
.set	push_cnvrt_integer_if_whole_nmb,	0x30D
.set	push_END_TAG,			0x263
.set	push_expr2_quantum,		0x2EA
.set	push_expr_quantum,			0x2E9
.set	push_Float,			0x30A
.set	push_Float_to_nonneg_int,		0x30B
.set	push_Float_to_rat,			0x30C
.set	push_internal_simplify,		0x4F8
.set	push_LIST_TAG,			0x264
.set	ARb_real_count,			0x5C2
.set	push_next_arb_int,			0x2EB
.set	push_next_arb_real,		0x2EC
.set	push_next_internal_var,		0x2ED
.set	push_offset_array,			0x3C4
.set	push_overflow_to_infinity,		0x30E
.set	push_parse_text,			0x3CA
.set	push_zstr,				0x48A
.set	push_quantum,			0x2EE
.set	push_quantum_pair,			0x2EF
.set	push_reversed_tail,		0x3BF
.set	push_round_Float,			0x310
.set	reductum_index,			0x2F0
.set	remaining_element_count,		0x3C3
.set	remaining_factors_index,		0x2F1
.set	reset_control_flags,		0x2F4
.set	reset_estack_size,			0x2F3
.set	re_index,				0x2F2
.set	should_and_did_push_approx_arg2,	0x311
.set	signum_Float,			0x312
.set	top_estack,			0x109
.set	is_tail_independent_of,		0x2DD
.set	push_transpose_aux,		0x3C1
.set	TokenizeSymName,			0x80
.set	push_expression,			0x44D
.set	ARb_int_count,			0x5C3
.set	push_long_to_integer,		0x4E3
.set	push_ulong_to_integer,		0x4E4
.set	push_ushort_to_integer,		0x4E5
.set	is_never0,				0x577
.set	is_minus1,				0x508
.set	is_negative,			0x575
.set	integer_non_unknown,		0x50C
.set	is_nonnegative,			0x574
.set	is_nonpositive,			0x576
.set	is_positive,			0x573
.set	is_whole_number,			0x50B
.set	is0,				0x269
.set	is1,				0x2FD
.set	is_totally_polynomial,		0x56C
.set	is_polynomial_in_var_or_kern,	0x56B
.set	is_constant,			0x593
.set	is_variable,			0x488
.set	negate_top,			0x525
.set	add1_to_top,			0x51D
.set	and_onto_top,			0x579
.set	add_to_top,			0x518
.set	push_simplify,			0x44E
.set	subtract_from_top,			0x51B
.set	subtract1_from_top,		0x51E
.set	ABT_dialog,			0x10D
.set	CAT_dialog,			0x125
.set	EV_captureEvents,			0xC6
.set	EV_centralDispatcher,		0x156
.set	EV_clearPasteString,		0xC7
.set	EV_defaultHandler,			0x157
.set	EV_eventLoop,			0x158
.set	EV_getc,				0xC8
.set	EV_getSplitRect,			0xC9
.set	EV_hook,				0x2A3
.set	EV_notifySwitchGraph,		0xCA
.set	EV_paintOneWindow,			0xCB
.set	EV_paintWindows,			0xCC
.set	EV_registerMenu,			0x159
.set	EV_restorePainting,		0xCD
.set	EV_sendEvent,			0xCE
.set	EV_sendEventSide,			0xCF
.set	EV_sendString,			0xD0
.set	EV_setCmdCheck,			0xD1
.set	EV_setCmdState,			0xD2
.set	EV_setFKeyState,			0xD3
.set	EV_startApp,			0xD4
.set	EV_startSide,			0xD5
.set	EV_startTask,			0xD6
.set	EV_suspendPainting,		0xD7
.set	EV_switch,				0xD8
.set	MO_option,				0x447
.set	MO_currentOptions,			0xD9
.set	MO_defaults,			0xDA
.set	MO_digestOptions,			0xDB
.set	MO_isMultigraphTask,		0xDC
.set	MO_modeDialog,			0xDD
.set	MO_notifyModeChange,		0xDE
.set	MO_sendQuit,			0xDF
.set	handleVarLinkKey,			0x129
.set	handleRclKey,			0x14F
.set	ModeSettings,			0x447
.set	AB_prodid,				0x29D
.set	AB_prodname,			0x29E
.set	AB_serno,				0x29F
.set	CB_fetchTEXT,			0xC2
.set	CB_replaceTEXT,			0xC1
.set	CU_restore,			0xC3
.set	CU_start,				0xC4
.set	CU_stop,				0xC5
.set	EX_patch,				0x15A
.set	HelpKeys,				0x181
.set	idle,				0x29B
.set	NeedStack,				0xA4
.set	off,				0x29A
.set	OSCheckBreak,			0xEC
.set	OSClearBreak,			0xED
.set	OSContrastDn,			0x297
.set	OSContrastUp,			0x296
.set	OSdequeue,				0x3AA
.set	OSDisableBreak,			0xEF
.set	OSEnableBreak,			0xEE
.set	OSenqueue,				0x3A9
.set	OSFreeTimer,			0xF1
.set	OSqclear,				0x3AD
.set	OSqhead,				0x3AC
.set	OSqinquire,			0x3AB
.set	OSRegisterTimer,			0xF0
.set	OSReset,				0x294
.set	OSSetSR,				0x29C
.set	OSTimerCurVal,			0xF2
.set	OSTimerExpired,			0xF3
.set	OSTimerRestart,			0xF4
.set	QModeKey,				0x182
.set	QSysKey,				0x183
.set	SumStoChkMem,			0x295
.set	WordInList,			0x184
.set	XR_stringPtr,			0x293
.set	CU_cursorState,			0x503
.set	FiftyMsecTick,			0x4FC
.set	ReleaseVersion,			0x440
.set	ReleaseDate,			0x43F
.set	AB_getGateArrayVersion,		0x15E
.set	EX_getBasecodeParmBlock,		0x5DA
.set	ST_angle,				0xE0
.set	ST_batt,				0xE1
.set	ST_busy,				0xE2
.set	ST_eraseHelp,			0xE3
.set	ST_folder,				0xE4
.set	ST_graph,				0xE5
.set	ST_helpMsg,			0xE6
.set	ST_modKey,				0xE7
.set	ST_precision,			0xE8
.set	ST_readOnly,			0xE9
.set	ST_refDsp,				0xEB
.set	ST_stack,				0xEA
.set	ST_progressIncrement,		0x4DA
.set	ST_progressBar,			0x4D8
.set	ST_progressDismiss,		0x4DB
.set	ST_progressUpdate,			0x4D9
.set	AddSymToFolder,			0x70
.set	DerefSym,				0x79
.set	EM_moveSymFromExtMem,		0x161
.set	EM_moveSymToExtMem,		0x162
.set	EM_twinSymFromExtMem,		0x166
.set	FindSymInFolder,			0x71
.set	FolderAdd,				0x64
.set	FolderAddTemp,			0x73
.set	FolderClear,			0x66
.set	FolderCount,			0x6B
.set	FolderCur,				0x65
.set	FolderCurTemp,			0x72
.set	FolderDel,				0x66
.set	FolderDelAllTemp,			0x75
.set	FolderDelTemp,			0x74
.set	FolderFind,			0x67
.set	FolderGetCur,			0x68
.set	FolderOp,				0x69
.set	FolderRename,			0x6A
.set	HSymDel,				0x5F
.set	HSYMtoName,			0x7A
.set	IsMainFolderStr,			0x77
.set	MakeHSym,				0x282
.set	SymAdd,				0x5C
.set	SymAddMain,			0x5D
.set	SymAddTwin,			0x27F
.set	SymCmp,				0x81
.set	SymCpy,				0x82
.set	SymCpy0,				0x83
.set	SymDel,				0x5E
.set	SymDelTwin,			0x280
.set	SymFind,				0x60
.set	SymFindFirst,			0x6C
.set	SymFindFolderName,			0x6F
.set	SymFindHome,			0x62
.set	SymFindMain,			0x61
.set	SymFindNext,			0x6D
.set	SymFindPrev,			0x6E
.set	SymFindPtr,			0x283
.set	SymMove,				0x63
.set	TempFolderName,			0x76
.set	TokToStrN,				0x7C
.set	StrToTokN,				0x7B
.set	ClearUserDef,			0x7E
.set	CheckLinkLockFlag,			0x7F
.set	VarRecall,				0x85
.set	VarStore,				0x86
.set	QSysProtected,			0x88
.set	SetOK,				0x456
.set	checkCurrent,			0x121
.set	CheckReservedName,			0x8B
.set	CheckSysFunc,			0x89
.set	EX_stoBCD,				0xC0
.set	ValidateSymName,			0x84
.set	SymSysVar,				0x8C
.set	ResetSymFlags,			0x8E
.set	partial_len,			0x11C
.set	GetDataType,			0x435
.set	SmapTypeStrings,			0x436
.set	GetFuncPrgmBodyPtr,		0x43A
.set	free,				0xA3
.set	FreeHandles,			0x23B
.set	HeapAlloc,				0x90
.set	HeapAllocESTACK,			0x91
.set	HeapAllocHigh,			0x92
.set	HeapAllocHighThrow,		0x94
.set	HeapAllocPtr,			0xA2
.set	HeapAllocThrow,			0x93
.set	HeapAvail,				0x8F
.set	HeapCompress,			0x95
.set	HeapDeref,				0x96
.set	HeapEnd,				0xA1
.set	HeapFreeIndir,			0x98
.set	HeapFreePtr,			0xA3
.set	HeapFree,				0x97
.set	HeapGetHandle,			0x239
.set	HeapGetLock,			0x9B
.set	HeapLock,				0x9A
.set	HeapMax,				0x9C
.set	HeapMoveHigh,			0xA0
.set	HeapPtrToHandle,			0x23A
.set	HeapRealloc,			0x9D
.set	HeapSize,				0x9E
.set	HeapUnlock,			0x9F
.set	HLock,				0x99
.set	malloc,				0xA2
.set	HeapWalk,				0x12C
.set	HeapShuffle,			0x474
.set	EX_getArg,				0xBE
.set	EX_getBCD,				0xBF
.set	RemainingArgCnt,			0x3C3
.set	GKeyDown,				0x17F
.set	GKeyFlush,				0x180
.set	GKeyIn,				0x17E
.set	kbhit,				0x52
.set	ngetchx,				0x51
.set	OSGetStatKeys,			0x299
.set	OSInitBetweenKeyDelay,		0x249
.set	pushkey,				0x50
.set	OSInitKeyInitDelay,		0x248
.set	alphaLockOn,			0x481
.set	alphaLockOff,			0x482
.set	SetAlphaStatus,			0x163
.set	GetAlphaStatus,			0x164
.set	KeyYesOrNo,			0x3EB
.set	OSFastArrows,			0x15C
.set	restoreAlphaLock,			0x483
.set	KB_AUTOREPEAT,			0x15C
.set	BitmapGet,				0x185
.set	BitmapInit,			0x186
.set	BitmapPut,				0x187
.set	BitmapSize,			0x188
.set	ClrScr,				0x19E
.set	DrawChar,				0x1A4
.set	DrawClipChar,			0x191
.set	DrawClipEllipse,			0x192
.set	DrawClipLine,			0x193
.set	DrawClipPix,			0x194
.set	DrawClipRect,			0x195
.set	DrawFkey,				0x1A5
.set	DrawIcon,				0x1A6
.set	DrawLine,				0x1A7
.set	DrawMultiLines,			0x196
.set	DrawPix,				0x1A8
.set	CalcBitmapSize,			0x3EF
.set	DrawStr,				0x1A9
.set	DrawStrWidth,			0x197
.set	LineTo,				0x19C
.set	FillLines2,			0x199
.set	FillTriangle,			0x198
.set	FontCharWidth,			0x190
.set	FontGetSys,			0x18E
.set	FontSetSys,			0x18F
.set	GetPix,				0x19F
.set	ScrRect,				0x2F
.set	MoveTo,				0x19D
.set	PortRestore,			0x1A3
.set	PortSet,				0x1A2
.set	QScrRectOverlap,			0x18D
.set	RestoreScrState,			0x1A1
.set	SaveScrState,			0x1A0
.set	ScrRectFill,			0x189
.set	ScrRectOverlap,			0x18A
.set	ScrRectScroll,			0x18B
.set	ScrRectShift,			0x18C
.set	ScrToHome,				0x2E
.set	ScrToWin,				0x2D
.set	SetCurAttr,			0x19A
.set	SetCurClip,			0x19B
.set	ClientToScr,			0x42C
.set	DrawStrWidthP,			0x3EE
.set	MakeScrRect,			0x42D
.set	DrawWinBorder,			0x27
.set	FirstWindow,			0x0
.set	MakeWinRect,			0x2C
.set	RectWinToScr,			0x2A
.set	RectWinToWin,			0x29
.set	WinActivate,			0x1
.set	WinAttr,				0x2
.set	WinBackground,			0x4
.set	WinBackupToScr,			0x3
.set	WinBegin,				0x5
.set	WinBitmapGet,			0x6
.set	WinBitmapPut,			0x7
.set	WinBitmapSize,			0x8
.set	WinChar,				0xA
.set	WinCharXY,				0x9
.set	WinClose,				0xB
.set	WinClr,				0xC
.set	WinDeactivate,			0xD
.set	WinDupStat,			0xE
.set	WinEllipse,			0xF
.set	WinFill,				0x10
.set	WinFillLines2,			0x11
.set	WinFillTriangle,			0x12
.set	WinFont,				0x13
.set	WinGetCursor,			0x14
.set	WinHeight,				0x292
.set	WinHide,				0x15
.set	WinHome,				0x16
.set	WinLine,				0x17
.set	WinLineNC,				0x18
.set	WinLineRel,			0x1A
.set	WinLineTo,				0x19
.set	WinMoveCursor,			0x1B
.set	WinMoveRel,			0x1D
.set	WinMoveTo,				0x1C
.set	WinOpen,				0x1E
.set	WinPixGet,				0x1F
.set	WinPixSet,				0x20
.set	WinRect,				0x21
.set	WinReOpen,				0x22
.set	WinScrollH,			0x23
.set	WinScrollV,			0x24
.set	WinStr,				0x25
.set	WinStrXY,				0x26
.set	WinWidth,				0x291
.set	DrawStaticButton,			0x35
.set	SetWinClip,			0x42E
.set	BN_powerMod,			0x123
.set	BN_power17Mod,			0x122
.set	BN_prodMod,			0x124
.set	cdecrypt,				0x127
.set	MD5Done,				0x257
.set	MD5Final,				0x256
.set	MD5Init,				0x254
.set	MD5Update,				0x255
.set	Dialog,				0x30
.set	DialogAdd,				0x33
.set	DialogDo,				0x32
.set	DialogNew,				0x34
.set	DlgMessage,			0x1B4
.set	VarNew,				0x28E
.set	VarOpen,				0x28C
.set	VarSaveAs,				0x28D
.set	ERD_dialog,			0x151
.set	ERD_process,			0x152
.set	ER_catch,				0x154
.set	ER_success,			0x155
.set	ER_throwVar,			0x153
.set	find_error_message,		0x2C1
.set	EM_abandon,			0x15B
.set	EM_findEmptySlot,			0x15F
.set	EM_GC,				0x160
.set	EM_survey,				0x165
.set	EM_write,				0x167
.set	FL_addCert,			0x169
.set	FL_download,			0x16A
.set	FL_getCert,			0x16C
.set	FL_getHardwareParmBlock,		0x16B
.set	FL_getVerNum,			0x16D
.set	FL_write,				0x171
.set	BatTooLowFlash,			0x434
.set	FlashMemoryEnd,			0x43D
.set	EM_blockVerifyErase,		0x15D
.set	getcalc,				0x54
.set	LIO_Get,				0x57
.set	LIO_GetMultiple,			0x59
.set	LIO_Receive,			0x58
.set	LIO_RecvData,			0x5B
.set	LIO_Send,				0x56
.set	LIO_SendData,			0x5A
.set	LIO_SendProduct,			0x253
.set	OSCheckSilentLink,			0x24A
.set	OSLinkClose,			0x24E
.set	OSLinkCmd,				0x24B
.set	OSLinkOpen,			0x24D
.set	OSLinkReset,			0x24C
.set	OSLinkTxQueueActive,		0x252
.set	OSLinkTxQueueInquire,		0x251
.set	OSReadLinkBlock,			0x24F
.set	OSWriteLinkBlock,			0x250
.set	sendcalc,				0x55
.set	MenuAddIcon,			0x42
.set	MenuAddText,			0x41
.set	MenuBegin,				0x36
.set	MenuCheck,				0x37
.set	MenuEnd,				0x38
.set	MenuGetTopRedef,			0x40
.set	MenuKey,				0x39
.set	MenuNew,				0x43
.set	MenuOn,				0x3A
.set	MenuPopup,				0x3B
.set	MenuSubStat,			0x3C
.set	MenuTopRedef,			0x3F
.set	MenuTopSelect,			0x3E
.set	MenuTopStat,			0x3D
.set	MenuUpdate,			0x49
.set	PopupAddText,			0x44
.set	PopupClear,			0x46
.set	PopupDo,				0x47
.set	PopupNew,				0x45
.set	PopupText,				0x48
.set	VarCreateFolderPopup,		0x28F
.set	MenuLoad,				0x3F2
.set	MenuFlags,				0x3F4
.set	QMenuTopSelect,			0x41A
.set	DynMenuAdd,			0x3F1
.set	FKeyI_H,				0x592
.set	DynMenuChange,			0x3F0
.set	MenuItemDef,			0x3F3
.set	MenuOff,				0x419
.set	PopupBegin,			0x3F5
.set	PopupBeginDo,			0x3F6
.set	ceof,				0x128
.set	cfindfield,			0x12A
.set	cgetc,				0x12B
.set	cgetcertrevno,			0x2A0
.set	cgetflen,				0x12D
.set	cgetfnl,				0x12E
.set	cgetnl,				0x12F
.set	cgetns,				0x130
.set	cgetsn,				0x2A1
.set	copen,				0x132
.set	copensub,				0x133
.set	cputhdr,				0x134
.set	cputnl,				0x135
.set	cputns,				0x136
.set	cread,				0x137
.set	ctell,				0x138
.set	cwrite,				0x139
.set	CertificateMemory,			0x43E
.set	sprintf,				0x53
.set	cmd_clrdraw,			0x32D
.set	cmd_clrgraph,			0x32F
.set	cmd_clrhome,			0x330
.set	cmd_clrio,				0x331
.set	cmd_clrtable,			0x332
.set	cmd_custmoff,			0x335
.set	cmd_custmon,			0x336
.set	cmd_disp,				0x33D
.set	cmd_dispg,				0x33E
.set	cmd_disphome,			0x33F
.set	cmd_disptbl,			0x340
.set	cmd_fnoff,				0x34D
.set	cmd_fnon,				0x34E
.set	cmd_get,				0x350
.set	cmd_getcalc,			0x351
.set	cmd_graph,				0x353
.set	cmd_input,				0x356
.set	cmd_inputstr,			0x357
.set	cmd_newprob,			0x367
.set	cmd_output,			0x369
.set	cmd_pause,				0x36B
.set	cmd_printobj,			0x370
.set	cmd_prompt,			0x371
.set	cmd_rclgdb,			0x381
.set	cmd_send,				0x387
.set	cmd_sendcalc,			0x388
.set	cmd_sendchat,			0x389
.set	cmd_stogdb,			0x390
.set	cmd_style,				0x392
.set	cmd_table,				0x393
.set	cmd_shade,				0x38A
.set	cmd_newpic,			0x365
.set	cmd_newplot,			0x366
.set	cmd_pxlon,				0x37B
.set	cmd_circle,			0x32C
.set	cmd_cyclepic,			0x339
.set	cmd_randseed,			0x380
.set	cmd_line,				0x358
.set	cmd_andpic,			0x32A
.set	cmd_blddata,			0x32B
.set	cmd_clrerr,			0x32E
.set	cmd_drawparm,			0x343
.set	cmd_exit,				0x34A
.set	cmd_copyvar,			0x333
.set	cmd_cubicreg,			0x334
.set	cmd_custom,			0x337
.set	cmd_cycle,				0x338
.set	cmd_drawpol,			0x344
.set	cmd_delfold,			0x33A
.set	cmd_delvar,			0x33B
.set	cmd_dialog,			0x33C
.set	cmd_drawinv,			0x342
.set	cmd_drawfunc,			0x341
.set	cmd_linehorz,			0x359
.set	cmd_linetan,			0x35A
.set	cmd_else,				0x345
.set	cmd_endfor,			0x346
.set	cmd_for,				0x34F
.set	cmd_if,				0x354
.set	cmd_ifthen,			0x355
.set	cmd_linreg,			0x35C
.set	cmd_expreg,			0x34B
.set	cmd_lnreg,				0x35D
.set	cmd_logistic,			0x360
.set	cmd_sinreg,			0x38C
.set	cmd_twovar,			0x398
.set	cmd_onevar,			0x368
.set	cmd_showstat,			0x38B
.set	cmd_rplcpic,			0x386
.set	cmd_xorpic,			0x39B
.set	cmd_rclpic,			0x382
.set	cmd_pxlcircle,			0x377
.set	cmd_stopic,			0x391
.set	cmd_fill,				0x34C
.set	cmd_goto,				0x352
.set	cmd_popup,				0x36E
.set	cmd_endloop,			0x347
.set	cmd_endwhile,			0x349
.set	cmd_while,				0x39A
.set	cmd_try,				0x397
.set	cmd_endtry,			0x348
.set	cmd_passerr,			0x36A
.set	cmd_linevert,			0x35B
.set	cmd_plotsoff,			0x36C
.set	cmd_plotson,			0x36D
.set	cmd_slpline,			0x38D
.set	cmd_sortd,				0x38F
.set	cmd_sorta,				0x38E
.set	cmd_unlock,			0x399
.set	cmd_lock,				0x35F
.set	cmd_unarchiv,			0x449
.set	cmd_archive,			0x448
.set	cmd_pxlline,			0x379
.set	cmd_pxlhorz,			0x378
.set	cmd_pxlvert,			0x37D
.set	cmd_ptchg,				0x372
.set	cmd_ptoff,				0x373
.set	cmd_pxltext,			0x37C
.set	cmd_pton,				0x374
.set	cmd_pxlchg,			0x376
.set	cmd_pxloff,			0x37A
.set	cmd_text,				0x394
.set	cmd_pttext,			0x375
.set	cmd_local,				0x35E
.set	cmd_movevar,			0x362
.set	cmd_rename,			0x383
.set	cmd_return,			0x385
.set	cmd_trace,				0x396
.set	cmd_toolbar,			0x395
.set	cmd_request,			0x384
.set	cmd_newdata,			0x363
.set	cmd_newfold,			0x364
.set	cmd_zoomin,			0x3A0
.set	cmd_zoomdata,			0x39D
.set	cmd_zoomdec,			0x39E
.set	cmd_zoomfit,			0x39F
.set	cmd_zoomint,			0x3A1
.set	cmd_zoomprev,			0x3A3
.set	cmd_zoombox,			0x39C
.set	cmd_zoomout,			0x3A2
.set	cmd_zoomrcl,			0x3A4
.set	cmd_zoomsqr,			0x3A5
.set	cmd_zoomsto,			0x3A7
.set	cmd_zoomtrig,			0x3A8
.set	cmd_zoomstd,			0x3A6
.set	cmd_medmed,			0x361
.set	cmd_quartreg,			0x37F
.set	cmd_quadreg,			0x37E
.set	cmd_powerreg,			0x36F
.set	TE_checkSlack,			0xA6
.set	TE_close,				0xA5
.set	TE_empty,				0xA7
.set	TE_focus,				0xA8
.set	TE_handleEvent,			0xA9
.set	TE_indicateReadOnly,		0xAA
.set	TE_isBlank,			0xAB
.set	TE_openFixed,			0xAD
.set	TE_open,				0xAC
.set	TE_pasteText,			0xAE
.set	TE_reopenPlain,			0xB0
.set	TE_reopen,				0xAF
.set	TE_select,				0xB1
.set	TE_shrinkWrap,			0xB2
.set	TE_unfocus,			0xB3
.set	TE_updateCommand,			0xB4
.set	longjmp,				0x267
.set	setjmp,				0x266
.set	strcat,				0x26E
.set	strchr,				0x274
.set	strcmp,				0x271
.set	strcpy,				0x26C
.set	strcspn,				0x275
.set	strerror,				0x27D
.set	strlen,				0x27E
.set	strncat,				0x26F
.set	strncmp,				0x272
.set	strncpy,				0x26D
.set	strpbrk,				0x276
.set	strrchr,				0x277
.set	strspn,				0x278
.set	strstr,				0x279
.set	strtok,				0x27A
.set	cmpstri,				0x16F
.set	stricmp,				0x407
.set	memucmp,				0x3CC
.set	memcpy,				0x26A
.set	memchr,				0x273
.set	memcmp,				0x270
.set	_memset,				0x27B
.set	memmove,				0x26B
.set	memset,				0x27C
.set	push_gcd_then_cofactors,		0x59E
.set	are_units_consistent,		0x40F
.set	assign_between,			0x2AC
.set	push_mrow_aux,			0x31B
.set	CharNumber,			0x113
.set	CheckGraphRef,			0x7D
.set	ST_flags,				0x443
.set	ck_valid_float,			0x1E5
.set	_bcd_math,				0xB5
.set	cleanup_de_mem,			0x1EC
.set	cleanup_seq_mem,			0x1D7
.set	clear_error_context,		0x44C
.set	compare_numbers,			0x50D
.set	convert_to_TI_92,			0x258
.set	CountGrFunc,			0x1D5
.set	cpt_gr_fun,			0x1D1
.set	cpt_gr_param,			0x1D2
.set	cpt_gr_polar,			0x1D3
.set	GT_ValidGraphRanges,		0x222
.set	CptFuncX,				0x1B9
.set	CptIndep,				0x1C9
.set	CptLastIndepDE,			0x1EF
.set	CreateEmptyList,			0x1E6
.set	CTypeTable,			0x442
.set	CustomBegin,			0x14A
.set	CustomEnd,				0x14C
.set	CustomFree,			0x150
.set	CustomMenuItem,			0x14B
.set	DataTypeNames,			0x43B
.set	de_initRes,			0x1F0
.set	de_loop,				0x1EB
.set	de_rng_no_graph,			0x2A2
.set	delete_list_element,		0x2AF
.set	deStepCk,				0x1F9
.set	did_push_divide_units,		0x3AE
.set	did_push_lincf,			0x572
.set	did_push_var_val,			0x2AD
.set	divide_top,			0x527
.set	does_push_fetch,			0x2AE
.set	dv_create_graph_titles,		0x117
.set	dv_findColumn,			0x119
.set	TIOS_EV_getAppID,			0x454
.set	EQU_deStatus,			0x16E
.set	EQU_getNameInfo,			0x120
.set	EQU_select,			0x11E
.set	EQU_setStyle,			0x11F
.set	ER_throwFrame,			0x507
.set	ERD_dismissNotice,			0x476
.set	ERD_notice,			0x475
.set	estack_to_float,			0x469
.set	EV_appA,				0x452
.set	EV_appB,				0x453
.set	EV_appSide,			0x458
.set	EV_currentApp,			0x45C
.set	EV_errorCode,			0x46D
.set	TIOS_strtol,			0x4FF
.set	EV_quit,				0x48E
.set	EV_runningApp,			0x45D
.set	execute_graph_func,		0x1D0
.set	TokenizeName,			0x3E9
.set	GZ_Square,				0x234
.set	Regraph,				0x1B6
.set	gr_initCondName,			0x1C8
.set	grFuncName,			0x1C7
.set	GT_SaveAs,				0x21C
.set	GT_Open,				0x21B
.set	FindFunc,				0x1C5
.set	FindGrFunc,			0x1C6
.set	FirstNonblank,			0x4DE
.set	FirstSeqPlot,			0x1D6
.set	fix_loop_displacements,		0x170
.set	FLOATTAB,				0x464
.set	ForceFloat,			0x47D
.set	gen_version,			0x259
.set	freeIdList,			0x4D6
.set	gr_DelFolder,			0x1CC
.set	FuncLineFlt,			0x1BF
.set	GetStatValue,			0x11B
.set	GetSysGraphRef,			0x8A
.set	GM_Derivative,			0x1B0
.set	GM_DistArc,			0x1B1
.set	get_lb,				0x516
.set	get_list_indices,			0x2B8
.set	get_matrix_indices,		0x2B9
.set	get_ub,				0x517
.set	GM_Inflection,			0x1AD
.set	GM_Integrate,			0x1AC
.set	GetTagStr,				0x46C
.set	GM_Intersect,			0x1AB
.set	GM_Math1,				0x1AF
.set	GM_Shade,				0x1B2
.set	GM_TanLine,			0x1AE
.set	GM_Value,				0x1AA
.set	gr_add_fldpic,			0x1F6
.set	gr_ck_solvergraph,			0x1FA
.set	gr_CptIndepInc,			0x1CA
.set	gr_de_value,			0x1ED
.set	gr_del_locals,			0x1CB
.set	gr_del_vars_in_folder,		0x1F1
.set	gr_DispLabels,			0x1E3
.set	GR_Pan,				0x1C4
.set	gr_de_axes_lbl,			0x1F2
.set	gr_execute_de,			0x1F3
.set	gr_execute_seq,			0x1D4
.set	gr_find_de_result,			0x1E8
.set	gr_delete_fldpic,			0x1F4
.set	gr_seq_value,			0x1DC
.set	gr_stopic,				0x1F7
.set	gr_xres_pixel,			0x1B8
.set	GR3_addContours,			0x1FB
.set	GR3_handleEvent,			0x1FE
.set	gr_find_el,			0x1F8
.set	gr_find_func_index,		0x1EE
.set	GraphActivate,			0x1FC
.set	GrLineFlt,				0x1BE
.set	gr_openFolder,			0x1CD
.set	GraphOrTableCmd,			0x1E4
.set	gr_remove_fldpic,			0x1F5
.set	GS_PlotAll,			0x202
.set	GS_PlotTrace,			0x201
.set	GT_BackupToScr,			0x20C
.set	GT_DspMsg,				0x212
.set	GR3_freeDB,			0x1FD
.set	GT_CalcDepVals,			0x20D
.set	GT_Format,				0x214
.set	GT_CenterGraphCursor,		0x20E
.set	GT_CursorKey,			0x20F
.set	GrAxes,				0x1B7
.set	GrClipLine,			0x1C0
.set	GT_DE_Init_Conds,			0x22A
.set	GT_DspFreeTraceCoords,		0x210
.set	GT_DspTraceCoords,			0x211
.set	GT_FreeTrace,			0x215
.set	GT_IncXY,				0x216
.set	GT_KeyIn,				0x217
.set	GT_QFloatCursorsInRange,		0x218
.set	GT_Regraph,			0x219
.set	GT_Regraph_if_neccy,		0x21A
.set	GT_SelFunc,			0x21D
.set	_du32u32,				0x2AA
.set	GT_Set_Graph_Format,		0x228
.set	GT_Error,				0x213
.set	GT_SetCursorXY,			0x21F
.set	GT_SetGraphRange,			0x21E
.set	GT_ShowMarkers,			0x220
.set	GT_Trace,				0x221
.set	GT_PrintCursor,			0x229
.set	GT_WinBound,			0x223
.set	GT_WinCursor,			0x224
.set	GZ_Decimal,			0x22D
.set	GZ_Fit,				0x22E
.set	GZ_InOut,				0x22F
.set	GZ_Integer,			0x230
.set	GZ_Previous,			0x231
.set	GZ_Recall,				0x232
.set	GZ_Standard,			0x235
.set	GZ_Stat,				0x236
.set	GZ_Store,				0x237
.set	GZ_Trig,				0x238
.set	InitDEAxesRng,			0x1E9
.set	InitDEMem,				0x1EA
.set	InitTimeSeq,			0x1D9
.set	GXcoord,				0x226
.set	GYcoord,				0x225
.set	NG_setup_graph_fun,		0x261
.set	PlotDel,				0x203
.set	PlotPut,				0x204
.set	QActivePlots,			0x20A
.set	QPlotActive,			0x20B
.set	seqStepCk,				0x1DE
.set	GZ_SetFactors,			0x233
.set	seqWebInit,			0x1DA
.set	SetGraphMode,			0x1B5
.set	setup_more_graph_fun,		0x1CE
.set	statFree,				0x40A
.set	has_different_variable,		0x5A0
.set	has_unit_base,			0x3AF
.set	hStrAppend,			0x45F
.set	index_after_match_endtag,		0x2B1
.set	index_if_pushed_binomial_info,	0x5A1
.set	index_if_pushed_qquad_info,	0x5A2
.set	index_reductum_with_tag_base,	0x59F
.set	index_rmng_factor,			0x565
.set	index_rmng_fctrs_start_base,	0x564
.set	index_rmng_fctrs_start_base_tag,	0x563
.set	index_rmng_fctrs_start_fctr_tag,	0x562
.set	init_list_indices,			0x2BA
.set	init_matrix_indices,		0x2BB
.set	init_unit_system,			0x3B0
.set	spike_chk_gr_dirty,		0x11A
.set	spike_in_editor,			0x116
.set	time_loop,				0x1D8
.set	is_cFloat_agg,			0x465
.set	is_complex_Float,			0x48B
.set	is_equivalent_to,			0x578
.set	is_executable,			0x25A
.set	is_neg_lead_numr_coef_re_part,	0x56D
.set	is_pathname,			0x3C6
.set	is_pos_int_and_eq_quantum,		0x509
.set	is_reciprocal_of_quantum,		0x50A
.set	is_term_improper,			0x556
.set	is_units_term,			0x3B1
.set	lead_conjunct_factor_index,	0x580
.set	lead_disjunct_term_index,		0x57E
.set	linear_degree,			0x571
.set	LIO_SendIdList,			0x3D0
.set	LoadSymFromFindHandle,		0x281
.set	LOC_formatDate,			0x590
.set	LOC_getLocalDateFormat,		0x58F
.set	LOC_localVersionDate,		0x591
.set	YCvtFtoP,				0x1BC
.set	next_token,			0x3C7
.set	next_var_or_kernel_index,		0x56E
.set	NG_control,			0x466
.set	nonblank,				0x3C8
.set	OO_appGetPublicStorage,		0x425
.set	OO_appIsMarkedDelete,		0x426
.set	OO_appMarkDelete,			0x427
.set	OO_AppNameToACB,			0x406
.set	OO_appSetPublicStorage,		0x429
.set	OO_Deref,				0x3FB
.set	TIOS_ldiv,				0x5BD
.set	OO_CondGetAttr,			0x3FA
.set	OO_Destroy,			0x423
.set	OO_DestroyAll,			0x4F5
.set	OO_firstACB,			0x451
.set	OO_GetAppAttr,			0x3FC
.set	OO_GetAttr,			0x3FD
.set	OO_HasAttr,			0x3FE
.set	OO_InstallAppHook,			0x490
.set	OO_InstallAppHookByName,		0x492
.set	OO_InstallSystemHook,		0x404
.set	OO_New,				0x3FF
.set	OO_NextACB,			0x402
.set	OO_PrevACB,			0x403
.set	OO_SetAppAttr,			0x400
.set	OO_SetAttr,			0x401
.set	OO_SuperFrame,			0x48F
.set	OO_UninstallAppHook,		0x491
.set	OO_UninstallAppHookByName,		0x493
.set	OO_UninstallSystemHook,		0x405
.set	or_onto_top,			0x57B
.set	OSModKeyStatus,			0x431
.set	paint_all_except,			0x11D
.set	ParseSymName,			0x78
.set	PlotDup,				0x207
.set	PlotGet,				0x205
.set	PlotInit,				0x206
.set	PlotLookup,			0x209
.set	PlotSize,				0x208
.set	primary_tag_list,			0x467
.set	pSymPG,				0x430
.set	push_ans_entry,			0x2B0
.set	push_auto_units_conversion,	0x3B2
.set	push_but_conjunct_factor,		0x582
.set	push_but_factor,			0x561
.set	push_but_term,			0x56A
.set	push_constant_factors,		0x55D
.set	push_constant_terms,		0x566
.set	push_dependent_factors,		0x55F
.set	push_dependent_terms,		0x568
.set	times_top,				0x522
.set	push_float_qr_fact,		0x2BC
.set	push_format,			0x315
.set	push_independent_factors,		0x560
.set	push_independent_terms,		0x569
.set	TIOS_abs,				0x5BA
.set	push_lu_fact,			0x2BD
.set	push_make_proper,			0x557
.set	push_minus_recip_of_quantum,	0x510
.set	push_negate_quantum_as_negint,	0x4F1
.set	push_nonconstant_factors,		0x55E
.set	push_nonconstant_terms,		0x567
.set	push_nonnumeric_factors,		0x55C
.set	push_parse_prgm_or_func_text,	0x3C9
.set	push_pi,				0x512
.set	push_pi_on_quantum,		0x513
.set	push_poly_deg_in_var_or_kernel,	0x570
.set	push_poly_qr,			0x59D
.set	push_quantum_as_nonnegative_int,	0x50E
.set	push_quantum_pair_as_pos_frac,	0x511
.set	push_reciprocal,			0x597
.set	push_reciprocal_of_quantum,	0x50F
.set	push_simplify_statements,		0x44F
.set	push_sq_matrix_to_whole_number,	0x3C0
.set	push_standardize,			0x558
.set	push_symbolic_qr_fact,		0x2BE
.set	push_trig,				0x535
.set	push_unit_system_list,		0x3B3
.set	push_var,				0x3CB
.set	push_var_kern_tail,		0x56F
.set	push_zero_partial_column,		0x3C2
.set	push0,				0x4E7
.set	push1,				0x4E8
.set	VarGraphRefBitsClear,		0x268
.set	YCvtFtoWin,			0x1B3
.set	QSkipGraphErr,			0x1E7
.set	QstatRcl,				0x40B
.set	raise_to_top,			0x529
.set	ReallocExprStruct,			0x14D
.set	recall_data_var,			0x112
.set	remaining_conjuncts_index,		0x581
.set	remaining_disjuncts_index,		0x57F
.set	replace_top_with_reciprocal,	0x52D
.set	replace_top2_with_and,		0x57A
.set	replace_top2_with_difference,	0x51C
.set	replace_top2_with_imre,		0x559
.set	replace_top2_with_or,		0x57C
.set	replace_top2_with_pow,		0x52A
.set	replace_top2_with_prod,		0x523
.set	replace_top2_with_ratio,		0x528
.set	replace_top2_with_sum,		0x519
.set	run_one_seq,			0x1DB
.set	ScrRectDivide,			0x28
.set	SearchExprStruct,			0x14E
.set	setup_unit_system,			0x3B4
.set	sf_width,				0x4D3
.set	SP_Define,				0x110
.set	spike_geo_titles,			0x115
.set	spike_optionD,			0x114
.set	spike_titles_in_editor,		0x118
.set	statEnd,				0x409
.set	statStart,				0x408
.set	_ds32s32,				0x2A8
.set	store_data_var,			0x111
.set	store_func_def,			0x2B4
.set	store_to_subscripted_element,	0x2B5
.set	_du16u16,				0x2A6
.set	tokenize_if_TI_92_or_text,		0x265
.set	unlock_more_graph_fun,		0x1CF
.set	ValidateStore,			0x8D
.set	VarOptList,			0x444
.set	VarSaveTitle,			0x290
.set	VarStoreLink,			0x87
.set	WinBeginPaint,			0x500
.set	WinBitmapSizeExt,			0x411
.set	WinEndPaint,			0x501
.set	WinLineExt,			0x47C
.set	WinRemove,				0x414
.set	XCvtFtoP,				0x1BD
.set	XCvtPtoF,				0x1BA
.set	_ms32s32,				0x2A9
.set	YCvtPtoF,				0x1BB
.set	did_map_aggregate_arg,		0x5B8
.set	did_push_approx_inflection_point,	0x5B0
.set	errno,				0x5D9
.set	estack_max_index,			0x5BF
.set	EV_flags,				0x5DF
.set	Float0Index,			0x5D0
.set	Float1Index,			0x5D1
.set	FloatExp1Index,			0x5D4
.set	FloatHalfIndex,			0x5E0
.set	FloatMinus1Index,			0x5D2
.set	FloatPiIndex,			0x5D3
.set	IM_re_tol,				0x5C1
.set	index_false,			0x5D6
.set	index_true,			0x5D5
.set	Integer0Index,			0x5CD
.set	Integer1Index,			0x5CE
.set	Integer2Index,			0x5E1
.set	IntegerMinus1Index,		0x5CF
.set	is_real,				0x5A9
.set	is_undefined,			0x5B7
.set	NG_such_that_index,		0x5D7
.set	OSCheckLinkOpen,			0x5E3
.set	RM_Type,				0x5DC
.set	TIOS_labs,				0x5BC
.set	RAtionalize_tol,			0x5C0
.set	replace_top_with_post_simplified,	0x5B6
.set	WinStrXYWrap,			0x5DB
.set	TIOS_div,				0x5BB
.set	_mu32u32,				0x2AB
.set	UpdateWindows,			0x2B
.set	push_user_func,			0x2B3
.set	_ds16u16,				0x2A4
.set	_mu16u16,				0x2A7
.set	NG_cleanup_graph_fun,		0x262
.set	_ms16u16,				0x2A5
.set	OSKeyScan,				0x298
.set	GD_HVLine,				0x178
.set	GD_Circle,				0x176
.set	GD_Pen,				0x179
.set	GD_Eraser,				0x17A
.set	GD_Text,				0x17B
.set	GD_Select,				0x17C
.set	GD_Contour,			0x17D
.set	GD_Line,				0x177
.set	GR3_paint3d,			0x1FF
.set	GR3_xyToWindow,			0x200
.set	GZ_Box,				0x22B
.set	GZ_Center,				0x22C
.set	HomeAlone,				0x506
.set	HS_getAns,				0x241
.set	HomeExecute,			0x10E
.set	HomePushEStack,			0x10F
.set	HS_getEntry,			0x242
.set	HS_countFIFO,			0x23D
.set	HS_freeFIFONode,			0x240
.set	HS_deleteFIFONode,			0x23E
.set	HS_freeAll,			0x23F
.set	HS_chopFIFO,			0x23C
.set	HS_getFIFONode,			0x243
.set	HS_newFIFONode,			0x245
.set	HS_pushFIFONode,			0x246
.set	HS_popEStack,			0x244
.set	push_matrix_product,		0x3C5
.set	push_list_times,			0x3BE
.set	push_list_plus,			0x3BD
.set	push_pow,				0x30F
.set	push_and,				0x5AB
.set	push_arg_plus_1,			0x51F
.set	push_arg_minus_1,			0x520
.set	push_assignment,			0x4DD
.set	push_difference,			0x51A
.set	push_dot_div,			0x4CD
.set	push_dot_add,			0x4A0
.set	push_dot_exponentiate,		0x596
.set	push_dot_mult,			0x4A1
.set	push_dot_sub,			0x4A2
.set	push_equals,			0x5A3
.set	push_exponentiate,			0x595
.set	push_to_sphere,			0x329
.set	push_factorial,			0x540
.set	push_greater_than,			0x5A5
.set	push_greater_than_or_equals,	0x5A7
.set	push_indir_name,			0x2B2
.set	push_degrees,			0x314
.set	push_less_than,			0x5A6
.set	push_less_than_or_equals,		0x5A8
.set	push_negate,			0x524
.set	push_not,				0x5AA
.set	push_not_equals,			0x5A4
.set	push_or,				0x5AC
.set	push_percent,			0x555
.set	push_radians,			0x4B3
.set	push_product,			0x521
.set	push_ratio,			0x526
.set	push_sum,				0x594
.set	push_substitute_simplify,		0x5B9
.set	push_substitute_using_such_that,	0x5BE
.set	push_substitute_no_simplify,	0x489
.set	push_to_cylin,			0x328
.set	did_push_to_polar,			0x313
.set	push_square,			0x52C
.set	push_setgraph,			0x322
.set	push_getmode,			0x318
.set	push_rand,				0x31F
.set	push_getkey,			0x316
.set	push_setmode,			0x323
.set	push_settable,			0x324
.set	push_switch,			0x327
.set	push_acos,				0x537
.set	push_abs,				0x543
.set	push_acosh,			0x53E
.set	push_1st_derivative,		0x5AE
.set	push_approx,			0x4F7
.set	push_asinh,			0x53D
.set	push_asin,				0x536
.set	push_augment,			0x496
.set	push_atanh,			0x53F
.set	push_atan,				0x538
.set	push_char,				0x497
.set	push_ceiling,			0x54B
.set	push_coldim,			0x498
.set	push_colnorm,			0x499
.set	push_comdenom,			0x59B
.set	push_conj,				0x547
.set	push_cosh,				0x53B
.set	push_cos,				0x533
.set	push_cross_product,		0x4CE
.set	push_cumsum,			0x49A
.set	push_csolve,			0x585
.set	push_czeros,			0x587
.set	push_def_int,			0x5B2
.set	push_desolve,			0x58B
.set	push_determinant,			0x49D
.set	push_diag,				0x49E
.set	push_dimension,			0x49F
.set	push_dotproduct,			0x4A3
.set	push_eigvc,			0x4CF
.set	push_eigvl,			0x4D0
.set	push_exp,				0x52E
.set	push_expand,			0x59A
.set	push_factor,			0x59C
.set	push_floor,			0x54A
.set	push_fractional_part,		0x54E
.set	push_gcd_numbers,			0x514
.set	push_randnorm,			0x4B5
.set	push_getfold,			0x317
.set	push_gettype,			0x319
.set	push_identity_mat,			0x4A4
.set	push_im,				0x546
.set	push_re,				0x545
.set	push_comb,				0x542
.set	push_perm,				0x541
.set	push_part,				0x31C
.set	push_instring,			0x31A
.set	push_integer_remainder,		0x550
.set	push_integer_part,			0x54D
.set	push_integer_gcd,			0x551
.set	push_integer_lcm,			0x552
.set	push_integer_quotient,		0x54F
.set	push_is_prime,			0x515
.set	push_left,				0x4A5
.set	did_push_series,			0x588
.set	push_lim,				0x5AD
.set	push_ln,				0x52F
.set	push_list_to_mat,			0x4A6
.set	push_log10,			0x530
.set	push_mat_to_list,			0x4A8
.set	push_matnorm,			0x4A7
.set	push_max,				0x58A
.set	push_median,			0x4AA
.set	push_mean,				0x4A9
.set	push_mid,				0x4AB
.set	push_min,				0x589
.set	push_mod,				0x54C
.set	push_mrow,				0x4AC
.set	did_push_anti_deriv,		0x5B1
.set	push_mrowadd,			0x4AD
.set	push_newmat,			0x4AF
.set	push_newlist,			0x4AE
.set	push_nint,				0x5B3
.set	push_nsolve,			0x583
.set	push_nth_derivative,		0x5AF
.set	push_denominator,			0x55B
.set	push_numerator,			0x55A
.set	push_max2,				0x599
.set	push_max1,				0x554
.set	push_min1,				0x553
.set	push_min2,				0x598
.set	push_ord,				0x4B0
.set	push_r_cis,			0x549
.set	push_pttest,			0x31D
.set	push_pxltest,			0x31E
.set	push_when,				0x57D
.set	push_zeros,			0x586
.set	push_prodlist,			0x4B2
.set	push_randmat,			0x4B4
.set	push_randpoly,			0x320
.set	push_right,			0x4B7
.set	push_rotate,			0x4B8
.set	push_round,			0x4B9
.set	push_row_echelon,			0x4BE
.set	push_red_row_ech,			0x4B6
.set	push_rowdim,			0x4BB
.set	push_rowadd,			0x4BA
.set	push_rowswap,			0x4BD
.set	push_rownorm,			0x4BC
.set	push_sequence,			0x4BF
.set	push_setfold,			0x321
.set	push_shift,			0x4C0
.set	push_sign,				0x544
.set	push_sin2,				0x531
.set	push_sin,				0x532
.set	push_simult,			0x4C1
.set	push_sinh,				0x53A
.set	push_solve,			0x584
.set	push_sqrt,				0x52B
.set	push_string,			0x326
.set	push_stddev,			0x4C3
.set	push_submat,			0x4C4
.set	push_str_to_expr,			0x325
.set	push_sumlist,			0x4C5
.set	push_summation,			0x5B4
.set	push_extended_prod,		0x5B5
.set	push_tan,				0x534
.set	push_tanh,				0x53C
.set	push_unitv,			0x4C8
.set	push_variance,			0x4C9
.set	push_rec_to_angle,			0x539
.set	push_phase,			0x548
.set	push_dense_poly_eval,		0x49C
.set	push_div_dif_1c,			0x58D
.set	push_div_dif_1f,			0x58C
.set	FCreate,				0x3D6
.set	FDelete,				0x3D7
.set	FEof,				0x3D8
.set	FFindNext,				0x3DA
.set	FGetC,				0x3DB
.set	FGetPos,				0x3DC
.set	FOpen,				0x3DE
.set	FRead,				0x3E0
.set	FSetBufSize,			0x3E2
.set	FSetPos,				0x3E1
.set	FSetVer,				0x3E4
.set	FStatus,				0x3E5
.set	FWrite,				0x3E7
.set	FFindFirst,			0x3D9
.set	FAccess,				0x3D4
.set	FClose,				0x3D5
.set	FGetSize,				0x3DD
.set	FPutC,				0x3DF
.set	FSetSize,				0x3E3
.set	FType,				0x3E6
.set	CkValidDelta,			0x1C3
.set	gr_active,				0x10B
.set	gr_flags,				0x463
.set	gr_other,				0x10C
.set	StepCk,				0x1DD
.set	CptDeltax,				0x1C1
.set	CptDeltay,				0x1C2
.set	gdb_len,				0x1E0
.set	gdb_recall,			0x1E2
.set	gdb_store,				0x1E1
.set	rngLen,				0x1DF
.set	NoCallBack,			0x31
.set	caddcert,				0x126
.set	cgetvernum,			0x131
.set	EM_writeToExtMem,			0x168
.set	OSVRegisterTimer,			0x284
.set	OSVFreeTimer,			0x285

.set	ScreenClear,			0x19E
.set	DrawStrXY,				0x1A9
.set	ArchiveErase,			0x16A+0x10
.set	ArchiveWrite,			0x171
.set	bcdadd,				0xB6
.set	bcdcmp,				0xBB
.set	bcddiv,				0xB9
.set	bcdbcd,				0xBD
.set	bcdmul,				0xB8
.set	bcdneg,				0xBA
.set	bcdsub,				0xB7
.set	bcdlong,				0xBC

.set	ST_showHelp,			0xE6
.set	DrawTo,				0x19C
.set	flush_link,			0x24D
.set	receive,				0x24F
.set	reset_link,			0x24C
.set	transmit,				0x250
.set	tx_free,				0x252

.set	SymFindFoldername,			0x6F
.set	MakeHsym,				0x282

|======================
|	RAM calls
|======================
.set	CALCULATOR,			_RAM_CALL_000
.set	LCD_WIDTH,			_RAM_CALL_001
.set	LCD_HEIGHT,			_RAM_CALL_002
.set	ams__ROM_base,			_RAM_CALL_003
.set	LCD_LINE_BYTES,			_RAM_CALL_004
.set	KEY_LEFT,			_RAM_CALL_005
.set	KEY_RIGHT,			_RAM_CALL_006
.set	KEY_UP,				_RAM_CALL_007
.set	KEY_DOWN,			_RAM_CALL_008
.set	KEY_UPRIGHT,			_RAM_CALL_009
.set	KEY_DOWNLEFT,			_RAM_CALL_00A
.set	KEY_DIAMOND,			_RAM_CALL_00B
.set	LCD_SIZE,			_RAM_CALL_00C
.set	KEY_SHIFT,			_RAM_CALL_00D
.set	ams__font_medium,		_RAM_CALL_00E
.set	ReturnValue,			_RAM_CALL_00F
.set	ams__kb_globals,		_RAM_CALL_010
.set	ams__Heap,			_RAM_CALL_011
.set	ams__FolderListHandle,		_RAM_CALL_012
.set	ams__MainHandle,		_RAM_CALL_013
.set	ROM_VERSION,			_RAM_CALL_014
.set	kernel__Idle,			_RAM_CALL_015
.set	kernel__Exec,			_RAM_CALL_016
.set	kernel__Ptr2Hd,			_RAM_CALL_017
.set	kernel__Hd2Sym,			_RAM_CALL_018
.set	kernel__LibsBegin,		_RAM_CALL_019
.set	kernel__LibsEnd,		_RAM_CALL_01A
.set	kernel__LibsCall,		_RAM_CALL_01B
.set	kernel__LibsPtr,		_RAM_CALL_01C
.set	kernel__LibsExec,		_RAM_CALL_01D
.set	kernel__HdKeep,			_RAM_CALL_01E
.set	kernel__ExtractFromPack,	_RAM_CALL_01F
.set	kernel__ExtractFile,		_RAM_CALL_020
|.set	LCD_MEM, 			_RAM_CALL_021
.set	LCD_MEM,			0x4c00
.set	ams__font_small,		_RAM_CALL_022
.set	ams__font_large,		_RAM_CALL_023
.set	ams__SYM_ENTRY.name,		_RAM_CALL_024
.set	ams__SYM_ENTRY.compat,		_RAM_CALL_025
.set	ams__SYM_ENTRY.flags,		_RAM_CALL_026
.set	ams__SYM_ENTRY.hVal,		_RAM_CALL_027
.set	ams__SYM_ENTRY.sizeof,		_RAM_CALL_028
.set	kernel__ExtractFileFromPack,	_RAM_CALL_029
.set	kernel__exit,			_RAM_CALL_02A
.set	kernel__atexit,			_RAM_CALL_02B
.set	kernel__RegisterVector,		_RAM_CALL_02C
.set	GHOST_SPACE,			_RAM_CALL_02D
.set	KERNEL_SPACE,			_RAM_CALL_02E
.set	kernel__SystemDir,		_RAM_CALL_02F

	|======================
	|	Variables
	|======================

.set	ams__kb_vars,		ams__kb_globals
.set	KEY_PRESSED_FLAG,	ams__kb_vars+0x1c
.set	ams__main_lcd,		LCD_MEM
.set	ams__globals,		LCD_MEM
.set	GETKEY_CODE,		ams__kb_vars+0x1e

|====================================================
|	Structures/Attributs
|====================================================

	|======================
	|	SYM_ENTRY
	|======================
.set	SYM_ENTRY.Name,		0
.set	SYM_ENTRY.Compat,	8
.set	SYM_ENTRY.Flags,	10
.set	SYM_ENTRY.Handle,	12
.set	SYM_ENTRY.Sizeof,	14

	|======================
	|	Drawing
	|======================
.set	A_REVERSE,	0
.set	A_NORMAL,	1
.set	A_XOR,		2
.set	A_SHADED,	3
.set	A_REPLACE,	4
.set	A_OR,		5
|.set	A_AND,		6
|.set	A_THICK1,	7
|.set	A_SHADE_V,	8
|.set	A_SHADE_H,	9
|.set	A_SHADE_NS,	10
|.set	A_SHADE_PS,	11

.set	B_NORMAL,	0x10
.set	B_ROUNDED,	0x20
.set	B_DOUBLE,	0x40
.set	B_CUT,		0x80

	|======================
	|	Mem
	|======================
.set	H_NULL,		0
.set	NULL,		0

	|======================
	|	VAT
	|======================
.set	FO_SINGLE_FOLDER,	0x01
.set	FO_RECURSE,		0x02
.set	FO_SKIP_TEMPS,		0x04
.set	FO_NOTEMPS,		0x04
.set	FO_RETURN_TWINS,	0x08
.set	FO_CKTWINS,		0x08
.set	FO_RETURN_FOLDER,	0x10
.set	FO_SKIP_COLLAPSE,	0x20

	|======================
	|	Folders
	|======================
.set	MAIN_FOLDER,	2
.set	FOLDER_TABLE,	3
.set	NOT_FOUND,	4
.set	BAD_FOLDER,	5

|====================================================
|	Macros
|====================================================

.macro 	DEFINE	ver
\ver:	.xdef	\ver
.endm

.macro	ROM_THROW	romcall
	.word	0xf800+\romcall
.endm

.macro	RC	romcall			|I use that to keep a correct indentation ;)
	.word	0xf800+\romcall
.endm

.macro	EXTRA_RAM_TABLE
	.even
_extraram:	.xdef	_extraram
.endm

.macro	EXTRA_RAM_ADDR	Num,Var,val89,val92
	.xdef	\Var
	.word	\val89
	.word	\val92
.set	\Var,	_extraramaddr__\Num
.endm

.macro	ROM_CALL	romcall
	movea.l	(0xc8),%a0
	movea.l	\romcall*4(%a0),%a0
	jsr	(%a0)
.endm

.macro	FAST_ROM_CALL	romcall,reg
	movea.l	\romcall*4(\reg),%a0
	jsr	(%a0)
.endm

.macro	ROM_PTR		romcall
	movea.l	(0xc8),%a0
	movea.l	\romcall*4(%a0),%a0
.endm

.macro	ER_throw	error
	.word	0xA000+\error
.endm


.macro	FAST_ROM_PTR	romcall,reg
	movea.l	\romcall*4(\reg),%a0
.endm

.endif
